/* @import url("https://fonts.googleapis.com/css2?family=Roboto:ital,wght@0,300;0,400;0,500;0,700;1,400&display=swap"); */
/*----------------------------------------*/
/*  testimonial free help page base css
/*----------------------------------------*/
.sp-wp-carousel-help-page * {
  margin: 0;
  padding: 0;
  box-sizing: border-box;
}

.sp-wp-carousel-help-page {
  font-family: Roboto, sans-serif;
  color: #444;
  background-color: #f0f4f7;
  padding: 30px 0 50px 40px;
  margin-left: -30px;
  margin-top: -20px;
}
#wpbody-content{
  padding-bottom: 0;
}
.sp_wp_carousel_page_wpcf_help #sp-wpcfree-review-notice{
  margin-bottom: 20px;
}
/*--------------------------------------
	- Layout
----------------------------------------*/
.sp-wp-carousel-help-page .col,
.sp-wp-carousel-help-page .col-lg-6 {
  position: relative;
  width: 100%;
  padding-right: 15px;
  padding-left: 15px;
}
/*----------------------------------------*/
/*  Grid Layout
/*----------------------------------------*/
.sp-wp-carousel-help-page .container {
  width: 100%;
  padding-right: 15px;
  padding-left: 15px;
  margin-right: auto;
  margin-left: auto;
}
@media (min-width: 576px) {
  .sp-wp-carousel-help-page .container {
    max-width: 540px;
  }
}
@media (min-width: 768px) {
  .sp-wp-carousel-help-page .container {
    max-width: 720px;
  }
}
@media (min-width: 992px) {
  .sp-wp-carousel-help-page .container {
    max-width: 960px;
  }
}
@media (min-width: 1170px) {
  .sp-wp-carousel-help-page .container {
    max-width: 1170px;
  }
}
@media (min-width: 1170px) {
  .sp-wp-carousel-help-page .container {
    max-width: 1170px;
  }
}

.sp-wp-carousel-help-page .row {
  display: flex;
  flex-wrap: wrap;
  margin-right: -15px;
  margin-left: -15px;
}

@media (min-width: 992px) {
  .sp-wp-carousel-help-page .col-lg-6 {
    flex: 0 0 50%;
    max-width: 50%;
  }
}
/*----------------------------------------*/
/*  header section css
/*----------------------------------------*/
.sp-wp-carousel-help-page .sp-wpc__help.header {
  background-color: #fff;
  padding: 50px 0;
  width: 90%;
  margin: 0 auto;
  margin-top: 40px;
  border-radius: 6px;
  box-shadow: 0px 0px 15px 0px rgba(0, 0, 0, 0.05);
}
@media screen and (min-width: 992px) {
  .sp-wp-carousel-help-page .sp-wpc__help.header {
    width: 80%;
  }
}
@media screen and (min-width: 1200px) {
  .sp-wp-carousel-help-page .sp-wpc__help.header {
    width: 960px;
  }
}
.sp-wp-carousel-help-page .sp-wpc__help.header .header-area .header-logo {
  text-align: center;
  position: relative;
}
.sp-wp-carousel-help-page .sp-wpc__help.header .header-area .header-logo span {
  transform: translateY(-30px);
  display: inline-block;
  font-size: 14px;
  font-weight: 500;
}
.sp-wp-carousel-help-page .sp-wpc__help.header .header-area .header-content {
  text-align: center;
  position: relative;
}
@media screen and (min-width: 1200px) {
  .sp-wp-carousel-help-page .upgrade-area .upgrade-img {
    right: 40px;
  }
}
.sp-wp-carousel-help-page .sp-wpc__help.header .header-area .header-content p {
  font-size: 17px;
  font-weight: 400;
  margin-top: 20px;
}
.sp-wp-carousel-help-page .sp-wpc__help.header .video-area {
  width: 100%;
  height: 340px;
  margin-top: 30px;
}
@media screen and (min-width: 768px) {
  .sp-wp-carousel-help-page .sp-wpc__help.header .video-area {
    width: 100%;
    height: 540px;
    margin-top: 30px;
  }
}
.sp-wp-carousel-help-page .sp-wpc__help.header .video-area iframe {
  width: 100%;
  height: 100%;
}
.sp-wp-carousel-help-page .sp-wpc__help.header .content-area {
  text-align: center;
}
.sp-wp-carousel-help-page .sp-wpc__help.header .content-area p {
  margin-top: 40px;
  font-size: 18px;
  line-height: 28px;
  font-weight: 400;
}
.sp-wp-carousel-help-page .sp-wpc__help.header .content-area p br {
  display: none;
}
@media screen and (min-width: 768px) {
  .sp-wp-carousel-help-page .sp-wpc__help.header .content-area p br {
    display: block;
  }
}
.Start_Displaying_Category_ {
  font-size: 16px;
  font-family: "Roboto";
  color: rgb( 255, 255, 255 );
  line-height: 1.5;
  text-align: center;
  position: absolute;
  left: 565.161px;
  top: 869.546px;
  z-index: 213;
}

.sp-wp-carousel-help-page .sp-wpc__help.header .content-area .content-button a {
  display: inline-block;
  text-decoration: none;
  padding: 18px 30px;
  border-radius: 4px;
  background-color: #1BA2AC;
  color: #fff;
  margin-right: 15px;
  font-size: 16px;
  font-weight: 500;
  margin-top: 48px;
}
.sp-wp-carousel-help-page .sp-wpc__help.header .content-area .content-button a:hover {
  background-color: #198E94;
}
.sp-wp-carousel-help-page .sp-wpc__help.header .content-area .content-button a:last-child {
  background-color: #d8e0e6;
  color: #818181;
}
.sp-wp-carousel-help-page .sp-wpc__help.header .content-area .content-button a:last-child:hover {
  background-color: #c0cbd5;
}

/*----------------------------------------*/
/*  upgrade section css
/*----------------------------------------*/

.sp-wp-carousel-help-page .sp-wpc__help.upgrade {
  background-color: #fff;
  width: 90%;
  margin: 0 auto;
  margin-top: 40px;
  border-radius: 5px;
  box-shadow: 0px 0px 15px 0px rgba(0, 0, 0, 0.05);
  overflow: hidden;
}
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .container {
  padding: 0 60px;
}
@media screen and (min-width: 992px) {
  .sp-wp-carousel-help-page .sp-wpc__help.upgrade {
    width: 80%;
  }
}
@media screen and (min-width: 1200px) {
  .sp-wp-carousel-help-page .sp-wpc__help.upgrade {
    width: 960px;
  }
}
.sp-wp-carousel-help-page .sp-wpc__help.header .header-area .header-logo::before,
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-pro .pro-content .pro-icon:before,
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-area .upgrade-img:before {
  position: absolute;
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  content: '';
  z-index: 99;
}
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-area .upgrade-img{
  position: absolute;
  bottom: -20px;
  right: 40px;
  opacity: .2;
  z-index: -1;
}
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-area {
  padding: 50px 30px;
  text-align: center;
  background-color: #157592;
  background: linear-gradient(-45deg, #22afba, #157592);
  color: #fff;
  position: relative;
  z-index: 1;
  box-shadow: 0px 0px 15px 0px rgba(0, 0, 0, 0.05);
}

.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-area h2 {
  font-size: 28px;
  font-weight: 500;
  color: #fff;
  line-height: 36px;
  margin-bottom: 0;
  margin-top: 0;
}

.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-area p {
  font-size: 18px;
  margin-top: 12px;
  font-weight: 400;
  margin-bottom: 0;
  line-height: 24px;
  padding: 0px 40px;
}
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-info {
  padding-top: 30px;
  padding-bottom: 40px;
  background-color: #f0faff;
}
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-info ul.upgrade-list li {
  display: flex;
  font-size: 18px;
  font-weight: 500;
  margin-top: 15px;
  list-style: none;
  line-height: 25px;
}
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-info ul.upgrade-list li img {
  width: 20px;
  margin-right: 15px;
  align-self: flex-start;
  margin-top: 3px;
}
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-pro {
  display: block;
  padding: 50px 0;
  width: 100%;
  margin: 0 auto;
}
@media screen and (min-width: 768px) {
  .sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-pro {
    display: flex;
    padding-right: 20px;
    padding-left: 20px;
  }
}
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-pro .pro-content {
  display: flex;
}
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-pro .pro-content .pro-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  flex-shrink: 0;
  position: relative;
}
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-pro .pro-content .pro-icon img {
  width: 100px;
  border-radius: 5px;
}
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-pro .pro-content .pro-text {
  align-self: center;
  margin-left: 30px;
}
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-pro .pro-content .pro-text h2 {
  font-size: 24px;
  font-weight: 500;
  line-height: 36px;
  margin-top: 0;
  margin-bottom: 0;
}
#wpfooter {
display: none;
}
@media screen and (min-width: 1170px) {
  .sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-pro .pro-content .pro-text h2 {
    font-size: 22px;
  }
}
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-pro .pro-content .pro-text p {
  font-size: 16px;
  font-weight: 400;
  margin-top: 5px;
}
@media screen and (min-width: 1170px) {
  .sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-pro .pro-content .pro-text p {
    font-size: 16px;
  }
}
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-pro .pro-btn {
  margin-left: auto;
  align-self: center;
  flex-shrink: 0;
  margin-top: 30px;
  text-align: center;
}
@media screen and (min-width: 768px) {
  .sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-pro .pro-btn {
    margin-top: 0;
  }
}
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-pro .pro-btn a {
  display: inline-block;
  text-decoration: none;
  padding: 15px 30px;
  background-color: #3fad43;
  color: #fff;
  border-radius: 5px;
  font-size: 16px;
  font-weight: 500;
}
.sp-wp-carousel-help-page .sp-wpc__help.upgrade .upgrade-pro .pro-btn a:hover {
  background-color: #1e7b25;
}

/*----------------------------------------*/
/*  testimonial section css
/*----------------------------------------*/
.sp-wp-carousel-help-page .sp-wpc__help.testimonial {
  width: 90%;
  margin: 0 auto;
  margin-top: 10px;
}

@media screen and (min-width: 992px) {
  .sp-wp-carousel-help-page .sp-wpc__help.testimonial {
    width: 80%;
  }
}
@media screen and (min-width: 1200px) {
  .sp-wp-carousel-help-page .sp-wpc__help.testimonial {
    width: 960px;
  }
}
.sp-wp-carousel-help-page .sp-wpc__help.testimonial .col,
.sp-wp-carousel-help-page .col-lg-6 {
  padding-right: 20px;
  padding-left: 20px;
}
.sp-wp-carousel-help-page .sp-wpc__help.testimonial .testimonial-area {
  margin-top: 30px;
}
.sp-wp-carousel-help-page .sp-wpc__help.testimonial .testimonial-area .testimonial-content {
  background-color: #fff;
  border-radius: 5px;
  position: relative;
  box-shadow: 0px 0px 15px 0px rgba(0, 0, 0, 0.05);
}
.sp-wp-carousel-help-page .sp-wpc__help.testimonial .testimonial-area .testimonial-content::after {
  position: absolute;
  content: "";
  border-style: solid;
  border-color: transparent;
  border-width: 18px 18px 0;
  border-top-color: #ffff;
  bottom: -16px;
  left: 45px;
}
.sp-wp-carousel-help-page .sp-wpc__help.testimonial .testimonial-area .testimonial-content p {
  padding: 25px 40px;
  font-size: 14px;
  font-weight: 400;
  line-height: 24px;
  font-style: italic;
}
.sp-wp-carousel-help-page .sp-wpc__help.testimonial .testimonial-area .testimonial-info {
  display: flex;
  margin-top: 25px;
  margin-left: 30px;
}
.sp-wp-carousel-help-page .sp-wpc__help.testimonial .testimonial-area .testimonial-info .img img{
  border-radius: 50%;
    height: 60px;
}
.sp-wp-carousel-help-page .sp-wpc__help.testimonial .testimonial-area .testimonial-info .info {
  margin-left: 15px;
  align-self: center;
}
.sp-wp-carousel-help-page .sp-wpc__help.testimonial .testimonial-area .testimonial-info .info h3 {
  font-size: 15px;
  margin-top: 0;
  margin-bottom: 0;
  font-weight: 500;
}
.sp-wp-carousel-help-page .sp-wpc__help.testimonial .testimonial-area .testimonial-info .info .star {
  display: flex;
  margin-top: 5px;
}
.sp-wpc__help.testimonial .testimonial-area .testimonial-info .info .star  .fa{
font-size: 15px;
margin-right: 1px;
color: #ffb900;

}
.sp-wp-carousel-help-page .sp-wpc__help.testimonial .testimonial-area .testimonial-info .info p {
  font-size: 12px;
  color: #808080;
  margin-top: 5px;
}
