/**
 *
 * ---------------------------------------------------------
 * SP FRAMEWORK CSS MAP
 * ---------------------------------------------------------
 *
 * 01. Base
 *     01. 01. Header
 *     01. 02. Sticky
 *     01. 03. Header Buttons
 *     01. 04. Navigation
 *     01. 05. Wrapper
 *     01. 06. Content
 *     01. 07. Section
 *     01. 08. Footer
 *     01. 09. Copyright
 *     01. 10. Show All Options
 *     01. 11. Search Input
 *     01. 12. Metabox
 *     01. 13. Help Tooltip
 * 02. Themes
 *     02. 01. Theme Dark
 *     02. 02. Theme Light
 * 03. Fields
 *     03. 01. Field
 *     03. 02. Field: accordion
 *     03. 03. Field: background
 *     03. 04. Field: backup
 *     03. 05. Field: border, spacing, dimensions, column, dimensions_advanced
 *     03. 06. Field: button_set
 *     03. 07. Field: checkbox, radio
 *     03. 08. Field: code_editor
 *     03. 09. Field: color
 *     03. 10. Field: color_group
 *     03. 11. Field: fieldset
 *     03. 12. Field: date
 *     03. 13. Field: gallery
 *     03. 14. Field: group
 *     03. 15. Field: icon
 *     03. 16. Field: image_select
 *     03. 17. Field: link_color
 *     03. 18. Field: media
 *     03. 19. Field: palette
 *     03. 20. Field: repeater
 *     03. 21. Field: select
 *     03. 22. Field: slider
 *     03. 23. Field: sortable
 *     03. 24. Field: sorter
 *     03. 25. Field: spinner
 *     03. 26. Field: switcher, switcherf
 *     03. 27. Field: tabbed
 *     03. 28. Field: text
 *     03. 29. Field: textarea
 *     03. 30. Field: typography
 *     03. 31. Field: upload
 *     03. 32. Field: wp_editor
 *     03. 33. Field: heading
 *     03. 34. Field: subheading
 *     03. 35. Field: submessage
 *     03. 36. Field: notice
 *     03. 37. Field: others
 * 04. Widget
 * 05. Customizer
 * 06. Taxonomy
 07. Profile
 * 08. Modal
 *     08. 01. Shortcode Modal
 *     08. 02. Gutenberg Modal
 *     08. 03. Icon Modal
 * 09. Helper
 * 10. Welcome Page
 * 11. Responsive
 * 12. Others
 *
 * ---------------------------------------------------------
 *
 */

/**
 * 01. Base
 */

.spf {
    position: relative;
}

.spf label {
    padding: 0;
    margin: 0;
    display: inline-block;
}

.spf-ab-icon {
    top: 2px;
}

#screen-meta-links+.spf-options {
    margin-top: 40px;
}

.spf-options {
    margin-top: 20px;
    margin-right: 20px;
}

/**
 * 01. 01. Header
 */

.spf-header {
    position: relative;
}

.spf-header-inner {
    padding: 25px;
}

.spf-header-inner h1 svg {
    float: left;
    height: 26px;
    width: 28px;
    margin-right: 8px;
    padding-top: 6px;
}
.spf-header-inner h1 {
    float: left;
    font-size: 18px;
    line-height: 38px;
    font-weight: 600;
    margin: 0;
    vertical-align: middle;
}

.spf-header-inner h1 small {
    font-size: 11px;
    font-weight: 500;
}

/**
 * 01. 02. Sticky
 */

.spf-sticky .spf-header-inner {
    position: fixed;
    z-index: 20;
    top: 32px;
    -moz-box-shadow: 0 5px 25px rgba(0, 0, 0, 0.125);
    -webkit-box-shadow: 0 5px 25px rgba(0, 0, 0, 0.125);
    box-shadow: 0 5px 25px rgba(0, 0, 0, 0.125);
}

/**
 * 01. 03. Header Buttons
 */


/**
 * 01. 03. Header Buttons
 */

 .spf-buttons {
    float: right;
    -moz-transition: opacity 0.2s;
    -o-transition: opacity 0.2s;
    -webkit-transition: opacity 0.2s;
    transition: opacity 0.2s;
}


.spf-buttons .button {
    margin: 0 4px;
    padding: 0px 16px;
    border-radius: 0;
    height: 38px;
    font-size: 13px;
    font-weight: 500;
    text-transform: uppercase;
    color: #ffffff;
}

.spf-buttons .button.spf-reset-all,
.spf-buttons .button.spf-reset-section {
    background-color: #cd3c3c !important;
    border-color: transparent !important;
    -webkit-box-shadow: none !important;
    box-shadow: none !important;
    text-shadow: none !important;
    border-radius: 4px;
    height: 38px;
    -webkit-transition: background-color .2s;
    transition: background-color .2s;
    color: #fff !important;
}
.spf-buttons .button.spf-save-ajax {
    background-color: #02cc7b;
    border-color: transparent;
    color: #fff !important;
    -webkit-box-shadow: none;
    box-shadow: none;
    text-shadow: none;
    border-radius: 4px;
    height: 38px;
    width: 75px;
    -webkit-transition: background-color .2s;
    transition: background-color .2s;
}
.spf-buttons .button.spf-save-ajax:hover {
    background-color: #02bb71;
}

.spf-buttons .button.spf-reset-section {
    background-color: #77777c !important;
}
.spf-buttons .button.spf-reset-section:hover {
    background-color: #616169 !important;
}
.spf-buttons .button.spf-reset-all:hover{
    background-color: #b82f2f !important;
}
.spf-buttons .button:focus {
    outline: none !important;
    box-shadow: none !important;
}

.spf-header-left {
    float: left;
}

.spf-header-right {
    float: right;
}


/**
 * 01. 04. Navigation
 */

.spf-nav {
    display: block;
    width: auto;
}

/* .spf-nav {
  display: block;
  position: relative;
  z-index: 10;
  float: left;
  width: 225px;
} */

.spf-nav ul {
    clear: left;
    margin: 0;
    list-style-type: none;
}

.spf-nav ul li {
    margin-bottom: 0;
}

.spf-nav ul li a {
    font-size: 13px;
    position: relative;
    display: block;
    padding: 14px 12px;
    text-decoration: none;
    -moz-transition: none;
    -o-transition: none;
    -webkit-transition: none;
    transition: none;
}

#spf-section-sp_wpcp_upload_options_1 .wpcp-admin-header .support a,
.spf-nav ul li a:focus {
    outline: none;
    -moz-box-shadow: none;
    -webkit-box-shadow: none;
    box-shadow: none;
}

.spf-nav ul li .spf-section-active:after {
    content: " ";
    position: absolute;
    right: 0;
    top: 50%;
    height: 0;
    width: 0;
    pointer-events: none;
    border: solid transparent;
    border-right-color: #fff;
    border-width: 4px;
    margin-top: -4px;
}

.spf-nav ul li .spf-arrow:after {
    content: "\f054";
    display: inline-block;
    font-family: "FontAwesome";
    font-size: 9px;
    line-height: 1;
    position: absolute;
    right: 10px;
    top: 50%;
    margin-top: -4px;
    -moz-transform: rotate(0);
    -ms-transform: rotate(0);
    -webkit-transform: rotate(0);
    transform: rotate(0);
}

.spf-nav ul li.spf-tab-active .spf-arrow:after {
    -moz-transform: rotate(90deg);
    -ms-transform: rotate(90deg);
    -webkit-transform: rotate(90deg);
    transform: rotate(90deg);
}

.spf-nav ul li.spf-tab-active ul {
    display: block;
}

.spf-nav ul ul {
    display: none;
    position: relative;
}

.spf-nav ul ul li a {
    font-size: 12px;
    padding: 12px 14px 12px 24px;
}

.spf-nav .fa {
    width: 20px;
    margin-right: 5px;
    font-size: 14px;
    text-align: center;
}

.spf-nav .spf-label-error {
    margin-left: 4px;
    vertical-align: top;
}

/**
 * 01. 05. Wrapper
 */

.spf-wrapper {
    position: relative;
}

/**
 * 01. 06. Content
 */

.spf-content {
    background-color: #fff;
    -moz-transition: opacity 0.2s;
    -o-transition: opacity 0.2s;
    -webkit-transition: opacity 0.2s;
    transition: opacity 0.2s;
}

/**
 * 01. 07. Section
 */

.spf-sections {
    float: left;
    width: 100%;
}

.spf-section {
    display: none;
}

.spf-section-title {
    display: none;
    padding: 20px 30px;
    /* background-color: #f5f5f5; */
    background-color: #18AFB9;
    border-top: 1px solid #eee;
    border-bottom: 1px solid #eee;
}

.spf-section-title h3 {
    margin: 0;
    padding: 0;
    font-size: 13px;
    font-weight: bold;
    text-transform: uppercase;
    color: #fff;
}

.spf-section-title .fa {
    margin-right: 5px;
}

/*
WP Carousel Pro Custom CSS.
*/

.sp-wpcp-options .spf-nav {
    width: 225px;
}

.sp-wpcp-options .spf-nav {
    display: block;
    position: relative;
    z-index: 10;
    float: left;
    width: 225px;
}

#sp_wpcp_shortcode_options .spf-nav ul li {
    display: inline-block;
    /* custom style */
}

.sp-wpcp-options .spf-nav-background {
    position: absolute;
    top: 0;
    left: 0;
    bottom: 0;
    z-index: 9;
    width: 225px;
}

.sp-wpcp-options .spf-content {
    position: relative;
    margin-left: 225px;
    background-color: #fff;
    -moz-transition: opacity 0.2s;
    -o-transition: opacity 0.2s;
    -webkit-transition: opacity 0.2s;
    transition: opacity 0.2s;
}

/**
 * 01. 08. Footer
 */

.spf-footer {
    padding: 20px;
    font-size: 11px;
}

/**
 * 01. 09. Copyright
 */

.spf-copyright {
    float: left;
    margin-top: 5px;
}

/**
 * 01. 10. Show All Options
 */

.spf-search-all .spf-nav-background,
.spf-search-all .spf-nav,
.spf-show-all .spf-nav-background,
.spf-show-all .spf-nav {
    display: none;
}

.spf-search-all .spf-content,
.spf-show-all .spf-content {
    margin-left: 0;
}

.spf-search-all .spf-section-title,
.spf-search-all .spf-section,
.spf-show-all .spf-section-title,
.spf-show-all .spf-section {
    display: block !important;
}

.spf-search-all .spf-section-title {
    display: none !important;
}

.spf-expand-all {
    float: left;
    padding: 0 8px;
    margin-right: 4px;
    z-index: 1;
    font-size: 14px;
    line-height: 29px;
    cursor: pointer;
    -webkit-user-select: none;
    user-select: none;
    -moz-border-radius: 2px;
    -webkit-border-radius: 2px;
    border-radius: 2px;
    -moz-transition: all 0.2s;
    -o-transition: all 0.2s;
    -webkit-transition: all 0.2s;
    transition: all 0.2s;
}

.spf-expand-all span {
    font-size: 11px;
    vertical-align: middle;
}

/**
 * 01. 11. Search Input
 */

.spf-search {
    float: left;
}

.spf-search input {
    margin: 0 2px 0 0;
    border: none;
    font-size: 12px;
    line-height: 29px;
    text-align: inherit;
    padding: 0 10px;
    -moz-border-radius: 2px;
    -webkit-border-radius: 2px;
    border-radius: 2px;
    -moz-box-shadow: none;
    -webkit-box-shadow: none;
    box-shadow: none;
}

.spf-search input:focus {
    -moz-box-shadow: none;
    -webkit-box-shadow: none;
    box-shadow: none;
}

.spf-saving .spf-buttons,
.spf-saving .spf-content {
    cursor: default;
    pointer-events: none;
    opacity: 0.75;
}

/**
 * 01. 12. Metabox
 */

.spf-metabox {
    margin: -6px -12px -12px -12px;
}

.spf-metabox .spf-section-title {
    padding: 20px;
}

.block-editor-page .spf-metabox {
    margin: -6px -14px -12px -14px;
}

.spf-metabox-restore {
    text-align: right;
    padding: 10px;
    border-top: 1px solid #eee;
}

.spf-metabox-restore .spf-button-cancel,
.spf-metabox-restore input {
    display: none;
}

.spf-metabox-restore span {
    -webkit-user-select: none;
    user-select: none;
}

.spf-metabox-restore input:checked~.spf-button-restore {
    display: none;
}

.spf-metabox-restore input:checked~.spf-button-cancel {
    display: inline-block;
}

#side-sortables .spf-section-title {
    padding: 12px;
}

#side-sortables .spf-field {
    padding: 12px;
}

#side-sortables .spf-field .spf-title {
    float: none;
    width: 100%;
    margin-bottom: 10px;
}

#side-sortables .spf-field .spf-fieldset {
    margin-left: 0;
}

#side-sortables .spf-notice {
    padding: 12px;
}

/**
 * 01. 13. Help Tooltip
 */

.spf-tooltip {
    position: absolute;
    z-index: 5000001;
    font-size: 12px;
    line-height: 1.4;
    text-align: center;
    text-decoration: none;
    padding: 6px 12px;
    max-width: 200px;
    color: #fff;
    background-color: #000;
    background-color: rgba(0, 0, 0, 0.85);
    -moz-border-radius: 4px;
    -webkit-border-radius: 4px;
    border-radius: 4px;
}

/**
 * 02. Themes
 */

/**
 * 02. 01. Theme Dark
 */

.spf-theme-dark .spf-header-inner {
    background-color: #050505;
}

.spf-theme-dark .spf-header-inner h1 {
    color: #fff;
}

.spf-theme-dark .spf-header-inner h1 small {
    color: #555;
}

.spf-theme-dark .spf-expand-all {
    color: #999;
    background-color: #222;
}

.spf-theme-dark .spf-expand-all:hover {
    color: #fff;
    background-color: #333;
}

.spf-theme-dark .spf-search input {
    color: #fff;
    background-color: #222;
}

.spf-theme-dark .spf-search:focus {
    background-color: #444;
}

.spf-theme-dark .spf-search::-webkit-input-placeholder {
    color: #666;
}

.spf-theme-dark .spf-nav ul li a {
    color: #999;
    background-color: #222;
    border-bottom: 1px solid #2f2f2f;
}

.spf-theme-dark .spf-nav ul li a:hover {
    color: #fff;
}

.spf-theme-dark .spf-nav ul li .spf-section-active {
    color: #fff;
    background-color: #111;
}

.spf-theme-dark .spf-nav ul ul li a {
    background-color: #191919;
    border-bottom: 1px solid #2f2f2f;
}

.spf-theme-dark .spf-nav ul ul li .spf-section-active {
    background-color: #101010;
}

.spf-theme-dark .spf-nav ul ul:before {
    background-color: rgba(34, 34, 34, 0.75);
}

.spf-theme-dark .spf-nav>ul>li:last-child>a {
    border-bottom: none;
}

.spf-theme-dark .spf-nav-background {
    background-color: #222;
}

.spf-theme-dark .spf-footer {
    color: #555;
    background-color: #050505;
}

/**
 * 02. 02. Theme Light
 */

.spf-theme-light .spf-container {
    border: 1px solid #e5e5e5;
    -moz-box-shadow: 0 0 15px rgba(0, 0, 0, 0.04);
    -webkit-box-shadow: 0 0 15px rgba(0, 0, 0, 0.04);
    box-shadow: 0 0 15px rgba(0, 0, 0, 0.04);
}

.spf-theme-light .spf-header-inner {
    border-bottom: 1px solid #cecece;
    background-color: #f5f5f5;
    background: linear-gradient(#fefefe, #f5f5f5);
}

.spf-theme-light .spf-header-inner h1 small {
    color: #999;
}

.spf-theme-light .spf-expand-all {
    color: #999;
    background-color: #fff;
    -moz-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
    -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
}

.spf-theme-light .spf-expand-all:hover {
    color: #555;
}

.spf-theme-light .spf-search input {
    color: #555;
    background-color: #fff;
    -moz-box-shadow: 0px 1px 1px rgba(0, 0, 0, 0.05);
    -webkit-box-shadow: 0px 1px 1px rgba(0, 0, 0, 0.05);
    box-shadow: 0px 1px 1px rgba(0, 0, 0, 0.05);
}

.spf-theme-light .spf-search input::-webkit-input-placeholder {
    color: #bbb;
}

.spf-theme-light .spf-nav {
    background: #f1f1f1;
}

.spf-theme-light .spf-nav ul li a {
    background-color: #1BA2AC;
    border-top: 1px solid #1BA2AC;
    border-right: 0px solid #E2E2E1;
    border-bottom: 1px solid #ddd;
    color: #fff;
    font-size: 12px;
    font-weight: 600;
    line-height: 1.4;
    padding: 14px 15px;
    text-transform: uppercase;
}
.sp_wpcp_shortcode_generator .spf-nav ul li a {
    border-right: 1px solid #E2E2E1;
}
.spf-theme-light .spf-nav ul li .spf-section-active {
    background-color: #fff;
    color: #000;
}

#sp_wpcp_shortcode_options .spf-theme-light .spf-nav ul li .spf-section-active {
    border-bottom: 1px solid #fff;
    border-top: 1px solid #1BA2AC;
    box-shadow: 0 3px 0 0 #1BA2AC inset;
}

.sp-wpcp-options.spf-theme-light .spf-nav ul li a {
    background: #efefef;
    color: #000;
    border-bottom: 1px solid #cecece;
    border-top: 1px solid #cecece;
}

.sp-wpcp-options.spf-theme-light .spf-nav ul li a:first-child {
    border-top: 0px solid transparent;
}

#sp_wpcp_shortcode_options .spf-theme-light .spf-nav ul li .spf-section-active i,
.sp-wpcp-options.spf-theme-light .spf-nav ul li .spf-section-active i {
    color: #1BA2AC;
}

.sp-wpcp-options.spf-theme-light .spf-nav ul li .spf-section-active {
    background-color: #fff;
    border-right: 0px solid #fff;
    border-bottom: 1px solid #cecece;
    border-top: 1px solid #fff;
    box-shadow: 4px 0 0 0 #18AFB9 inset;
}
.spf-field.spf-field-notice.pro_notice {
    padding-top: 0;
}
.spf-theme-light .spf-nav ul li .spf-section-active:after {
    display: none;
}

.spf-theme-light .spf-nav ul ul li a {
    background-color: #eee;
    border-bottom: 1px solid #e5e5e5;
}

.spf-theme-light .spf-nav-background {
    background-color: #ddd;
    border-right: 1px solid #cecece;
}

.spf-theme-light .spf-footer {
    color: #555;
    border-top: 1px solid #e5e5e5;
    background-color: #f5f5f5;
    background: linear-gradient(#fafafa, #f5f5f5);
}

/**
 * 03. Fields
 */

.spf-field {
    position: relative;
    padding: 22px 30px;
}
.spf-field.spf-field-carousel_type {
 padding-bottom: 0;
}

.spf-field p:first-child {
    margin-top: 0;
}

.spf-field p:last-child {
    margin-bottom: 0;
}

.spf-field:after,
.spf-field:before {
    content: " ";
    display: table;
}

.spf-field:after {
    clear: both;
}

.spf-field h4 {
    margin-top: 0;
}

.spf-field .spf-title {
    position: relative;
    width: 20%;
    float: left;
}

.spf-field .spf-title h4 {
    margin: 0;
    color: #23282d;
}

.spf-field .spf-fieldset {
    margin-left: 25%;
}

.spf-pseudo-field {
    padding: 0 5px 0 0 !important;
    display: inline-block;
}

.spf-pseudo-field+.spf-pseudo-field {
    border: 0;
}

.spf-pseudo-field pre {
    display: none;
}

/**
 * 03. 02. Field: accordion
 */

.spf-field-accordion .spf-field {
    padding: 20px;
}

.spf-field-accordion .spf-accordion-item {
    position: relative;
    margin-bottom: 5px;
}

.spf-field-accordion .spf-accordion-item h4 {
    font-size: 1em;
}

.spf-field-accordion .spf-accordion-title {
    display: block;
    cursor: pointer;
    position: relative;
    margin: 0;
    padding: 15px;
    min-height: 0;
    font-size: 100%;
    -webkit-user-select: none;
    user-select: none;
    border: 1px solid #e5e5e5;
    background-color: #fafafa;
    -moz-transition: border-color 0.15s;
    -o-transition: border-color 0.15s;
    -webkit-transition: border-color 0.15s;
    transition: border-color 0.15s;
}

.spf-field-accordion .spf-accordion-title:active,
.spf-field-accordion .spf-accordion-title:hover,
.spf-field-accordion .spf-accordion-title:focus {
    border: 1px solid #bbb;
    background-color: #fafafa;
    outline: none;
}

.spf-field-accordion .spf-accordion-icon {
    color: #aaa;
    width: 14px;
    text-align: center;
}

.spf-field-accordion .spf--icon {
    width: 18px;
    text-shadow: center;
}

.spf-field-accordion .spf-accordion-content {
    display: none;
    padding: 0;
    border: 1px solid #e5e5e5;
    border-top: none;
    background-color: #fff;
}

.spf-field-accordion .spf-accordion-open {
    display: block;
}

/**
 * 03. 03. Field: background
 */

.spf-field-background_adv select,
.spf-field-background select {
    width: 100%;
}

.spf-field-group .spf-field-background_adv .spf-field,
.spf-field-background_adv .spf-field,
.spf-field-background .spf-field {
    float: left;
    padding: 0;
    border: 0;
}

.spf-field-background_adv .spf--block,
.spf-field-background .spf--block {
    float: left;
    margin-bottom: 15px;
    box-sizing: border-box;
}

.spf-field-background_adv .spf--title,
.spf-field-background .spf--title {
    float: left;
    color: #999;
    margin-top: 3px;
    margin-right: 5px;
}

.spf-field-background_adv .spf--select,
.spf-field-background .spf--select {
    width: 25%;
    padding-right: 10px;
    box-sizing: border-box;
}

.spf-field-background_adv .spf--select .spf-field,
.spf-field-background .spf--select .spf-field {
    width: 100%;
}

.spf-field-background_adv .spf--media,
.spf-field-background .spf--media {
    width: 100%;
    padding-right: 10px;
}

.spf-field-background_adv .spf--media .spf-field,
.spf-field-background .spf--media .spf-field {
    width: 100%;
}

/**
* Custom CSS
*/

.spf-field.spf-field-wp_editor.wpcp_carousel_content_source .spf-fieldset,
.spf-field.spf-field-background_adv.wpcp_carousel_content_bg .spf-fieldset {
    margin-left: 0;
    margin-top: 35px;
}

.spf-field.spf-field-wp_editor.wpcp_carousel_content_source .spf-title,
.spf-field.spf-field-background_adv.wpcp_carousel_content_bg .spf-title {
    width: 100%;
}

.spf-field.spf-field-background_adv .spf--preview {
    font-size: 16px;
    line-height: 20px;
    padding: 20px;
    color: #222;
    border: 1px solid #eee;
    background-color: #fff;
    height: 150px;
    border-radius: 2.5px;
    user-select: none;
    -webkit-user-select: none;
    transition: background-color .2s, border-color .2s;
}

.spf-field.spf-field-background_adv .spf--block-preview {
    cursor: pointer;
    position: relative;
    overflow: hidden;
    margin-top: 10px;
    width: 100%;
}

.spf-field.spf-field-background_adv .spf--black-background {
    border-color: #000;
    background-color: #000;
}

.spf-field.spf-field-background_adv .spf--toggle {
    position: absolute;
    top: 5px;
    right: 10px;
    color: #999;
}

/**
 * 03. 04. Field: backup
 */

.spf-field-backup textarea {
    width: 100%;
    min-height: 200px;
    margin-bottom: 5px;
}

.spf-field-backup small {
    display: inline-block;
    margin: 5px;
}

.spf-field-backup hr {
    margin: 20px 0;
    border: none;
    border-bottom: 1px solid #e5e5e5;
}

/**
 * 03. 05. Field: border, spacing, dimensions, column, dimensions_advanced
 */

.spf-field-border .spf--left,
.spf-field-spacing .spf--left,
.spf-field-column .spf--left,
.spf-field-dimensions .spf--left,
.spf-field-dimensions_advanced .spf--left {
    float: left;
}

.spf-field-border .spf--input,
.spf-field-spacing .spf--input,
.spf-field-column .spf--input,
.spf-field-dimensions .spf--input,
.spf-field-dimensions_advanced .spf--input {
    float: left;
    margin-right: 10px;
    margin-bottom: 7px;
}

.spf-field-border .spf--input select,
.spf-field-spacing .spf--input select,
.spf-field-column .spf--input select,
.spf-field-dimensions .spf--input select,
.spf-field-dimensions_advanced .spf--input select {
    margin: 0;
    line-height: 22px;
}

.spf-field-border .spf--input input,
.spf-field-spacing .spf--input input,
.spf-field-column .spf--input input,
.spf-field-dimensions .spf--input input,
.spf-field-dimensions_advanced .spf--input input {
    line-height: 26px;
    float: left;
    margin: 0;
    padding: 0;
    width: 65px;
    max-width: 100%;
    text-align: center;
}
.spf-field-column .spf--input input{
    border-radius: 0 4px 4px 0;
}
.spf-field-spacing .spf--input input{
    border-radius: 4px 0 0 4px;
}
.spf-field-border .spf--input input{
    border-radius: 0;
}

.spf-field-border .spf--label,
.spf-field-spacing .spf--label,
.spf-field-column .spf--label,
.spf-field-dimensions .spf--label,
.spf-field-dimensions_advanced .spf--label {
    float: left;
    max-width: 100%;
    font-size: 12px;
    line-height: 26px;
    vertical-align: top;
    text-align: center;
    color: #555;
    border: 1px solid #ddd;
    background-color: #eee;
    padding: 0 6px;
}

.spf-field-border .spf--label-icon,
.spf-field-spacing .spf--label-icon,
.spf-field-column .spf--label-icon,
.spf-field-dimensions .spf--label-icon,
.spf-field-dimensions_advanced .spf--label-icon {
    min-width: 20px;
    border-right: 0;
    border-radius: 4px 0 0 4px;
    min-height: 28px;
    line-height: 28px;
}

.spf-field-border .spf--label-unit,
.spf-field-spacing .spf--label-unit,
.spf-field-column .spf--label-unit,
.spf-field-dimensions .spf--label-unit,
.spf-field-dimensions_advanced .spf--label-unit {
    color: #999;
    border-left: 0;
    border-radius: 0 4px 4px 0;
    min-height: 28px;
}

/**
 * 03. 06. Field: button_set
 */

.spf-field-button_set .spf--buttons {
    display: inline-block;
}

.spf-field-button_set .spf--button {
    position: relative;
    z-index: 1;
    float: left;
    cursor: pointer;
    padding: 7px 14px;
    min-width: 40px;
    text-align: center;
    color: #555;
    border: 1px solid #cccccc;
    background-color: #f7f7f7;
    user-select: none;
    -webkit-user-select: none;
    box-shadow: 0 1px 0 rgba(0, 0, 0, 0.1);
}

.spf-field-button_set .spf--button:first-child {
    border-radius: 4px 0 0 4px;
}

.spf-field-button_set .spf--button:last-child {
    border-radius: 0 4px 4px 0;
}

.spf-field-button_set .spf--button:not(:first-child) {
    margin-left: -1px;
}

.spf-field-button_set .spf--button:hover {
    background-color: #eee;
}

.spf-field-button_set .spf--active:hover,
.spf-field-button_set .spf--active {
    z-index: 2;
    color: #fff;
    border-color: #006799;
    background-color: #0085ba;
}

.spf-field-button_set input {
    display: none;
}

/**
 * 03. 07. Field: checkbox, radio
 */

.spf-field-checkbox ul,
.spf-field-radio ul {
    margin: 0;
    padding: 0;
    list-style-type: none;
    overflow-y: auto;
    max-height: 305px;
}

.spf-field-checkbox .spf--inline-list li,
.spf-field-radio .spf--inline-list li {
    display: inline-block;
    margin-right: 15px;
}

.spf-field-checkbox input[type="radio"]:checked:before,
.spf-field-radio input[type="radio"]:checked:before {
    line-height: 10px;
}

.spf-field-checkbox .spf-checker,
.spf-field-radio .spf-checker {
    cursor: pointer;
}

/**
 * 03. 08. Field: code_editor
 */

.spf-field-code_editor .CodeMirror {
    width: 100%;
    height: 400px;
    border: 1px solid #eee;
}

.spf-field-code_editor textarea {
    width: 100%;
    height: 400px;
}

/**
 * 03. 09. Field: color
 */

.spf-field-color>input {
    opacity: 0.75;
    width: 115px;
    max-width: 100%;
}

/**
 * 03. 10. Field: color_group
 */

.spf-field-color_group .spf--left {
    float: left;
    margin-right: 10px;
    margin-bottom: 5px;
}

.spf-field-color_group .spf--title {
    color: #999;
    margin-bottom: 5px;
}

/**
 * 03. 11. Field: fieldset
 */

.spf-field-fieldset .spf-fieldset-content {
    border: 1px solid #eee;
    background-color: #fff;
}

.spf-field-fieldset .spf-field {
    padding: 20px;
}

/**
 * 03. 12. Field: date
 */

.spf-field-date .spf--to {
    margin-left: 7px;
}

.spf-datepicker-wrapper {
    margin-top: 5px;
    width: auto;
    background-color: #fff;
    z-index: 9999999 !important;
    -moz-box-shadow: 0 0 30px rgba(0, 0, 0, 0.15);
    -webkit-box-shadow: 0 0 30px rgba(0, 0, 0, 0.15);
    box-shadow: 0 0 30px rgba(0, 0, 0, 0.15);
}

.spf-datepicker-wrapper * {
    float: none;
    margin: 0;
    padding: 0;
    font-family: inherit;
    font-weight: normal;
    font-style: normal;
    text-decoration: none;
    border: none;
    background: none;
    -moz-box-shadow: none;
    -webkit-box-shadow: none;
    box-shadow: none;
    -moz-border-radius: none;
    -webkit-border-radius: none;
    border-radius: none;
}

.spf-datepicker-wrapper .ui-widget-header,
.spf-datepicker-wrapper .ui-datepicker-header {
    color: #fff;
    background: #00a0d2;
}

.spf-datepicker-wrapper .ui-datepicker-header .ui-state-hover {
    cursor: pointer;
}

.spf-datepicker-wrapper .ui-datepicker-title {
    font-size: 14px;
    line-height: 40px;
    text-align: center;
}

.spf-datepicker-wrapper .ui-datepicker-prev,
.spf-datepicker-wrapper .ui-datepicker-next {
    position: static;
    top: auto;
    left: auto;
    right: auto;
    font-family: "FontAwesome";
    font-size: 12px;
    text-align: center;
    width: 41px;
    height: 40px;
    line-height: 40px;
    color: #fff;
    background-color: rgba(255, 255, 255, 0.1);
    text-rendering: auto;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

.spf-datepicker-wrapper .ui-datepicker-next span,
.spf-datepicker-wrapper .ui-datepicker-prev span {
    display: none;
}

.spf-datepicker-wrapper .ui-datepicker-prev {
    float: left;
}

.spf-datepicker-wrapper .ui-datepicker-next {
    float: right;
}

.spf-datepicker-wrapper .ui-datepicker-prev:before {
    content: '\f053';
}

.spf-datepicker-wrapper .ui-datepicker-next:before {
    content: '\f054';
}

.spf-datepicker-wrapper .ui-datepicker-prev-hover,
.spf-datepicker-wrapper .ui-datepicker-next-hover {
    opacity: 0.75;
}

.spf-datepicker-wrapper tbody .ui-datepicker-week-col {
    background-color: #f7f7f7;
}

.spf-datepicker-wrapper .ui-datepicker-buttonpane {
    padding: 10px;
    text-align: center;
    background-color: #f7f7f7;
}

.spf-datepicker-wrapper .ui-datepicker-buttonpane button {
    cursor: pointer;
    margin: 0 5px;
    padding: 7px 14px;
    border: 1px solid #eee;
    background-color: #fff;
}

.spf-datepicker-wrapper select {
    margin: 0 4px;
    color: #fff;
    border: 1px solid rgba(255, 255, 255, 0.5);
}

.spf-datepicker-wrapper select option {
    color: #555;
}

.spf-datepicker-wrapper table {
    font-size: 13px;
    border-collapse: collapse;
    width: 100%;
}

.spf-datepicker-wrapper thead {
    color: #fff;
    background: #32373c;
}

.spf-datepicker-wrapper th {
    text-align: center;
    padding: 7px;
    border: 1px solid #444;
}

.spf-datepicker-wrapper td {
    text-align: center;
    border: 1px solid #f4f4f4;
}

.spf-datepicker-wrapper td.ui-datepicker-other-month {
    border: transparent;
}

.spf-datepicker-wrapper td .ui-state-default {
    color: #555;
    width: auto;
    display: block;
    padding: 6px 12px;
}

.spf-datepicker-wrapper td .ui-state-active,
.spf-datepicker-wrapper td .ui-state-hover {
    color: #fff;
    background-color: #0073aa;
}

.spf-datepicker-wrapper td.ui-state-disabled .ui-state-default {
    opacity: 0.5;
}

/**
 * 03. 13. Field: gallery
 */

.spf-field-gallery input {
    display: none;
}

.spf-field-gallery ul {
    margin: 0;
    padding: 0;
    list-style-type: none;
}

.spf-field-gallery ul.sp-gallery-images li {
    display: inline-block;
    position: relative;
    padding: 4px;
    margin: 0 5px 10px 0;
    border: 1px solid #ccc;
    background-color: #f9f9f9;
    -moz-border-radius: 2px;
    -webkit-border-radius: 2px;
    border-radius: 2px;
    -moz-box-shadow: 0 1px 0 rgba(0, 0, 0, 0.08);
    -webkit-box-shadow: 0 1px 0 rgba(0, 0, 0, 0.08);
    box-shadow: 0 1px 0 rgba(0, 0, 0, 0.08);
}

.spf-field-gallery ul.sp-gallery-images li img {
    max-height: 100px;
    display: inline-block;
    vertical-align: middle;
}

.spf-field-gallery .button:focus,
.spf-field-gallery .button:hover,
.spf-field-gallery .button {
    margin-right: 5px;
    margin-bottom: 5px;
    /* SP Style */
    width: 110px;
    height: 110px;
    text-align: center;
    line-height: 15px;
    color: #fff;
    border: none;
    border-radius: 2px;
    display: flex;
    justify-content: center;
    flex-direction: column;
    font-weight: 600;
}

.spf-field-gallery .button-primary.spf-button {
    background: #4eb631;
    box-shadow: none;
    text-shadow: none;
}

.spf-field-gallery .button.spf-edit-gallery {
    background: #6a7885;
}

.spf-field-gallery .button i {
    font-size: 24px;
    margin-bottom: 10px;
}

.spf-field-gallery a,
.spf-field-gallery li {
    float: left;
}

/**
 * 03. 14. Field: group
 */

.spf-field-group .spf-field {
    padding: 20px;
}

.spf-field-group .spf-cloneable-hidden {
    display: none !important;
}

.spf-field-group .spf-cloneable-wrapper {
    position: relative;
}

.spf-field-group .spf-cloneable-item {
    display: none;
    position: relative;
    margin-bottom: 5px;
}

.spf-field-group .spf-cloneable-item h4 {
    font-size: 1em;
}

.spf-field-group .ui-accordion .spf-cloneable-item {
    display: block;
}

.spf-field-group .spf-cloneable-content {
    border: 1px solid #e5e5e5;
    background: #fff;
}

.spf-field-group .spf-cloneable-title {
    display: block;
    cursor: pointer;
    position: relative;
    margin: 0;
    padding: 15px 65px 15px 10px;
    min-height: 0;
    font-size: 100%;
    border: 1px solid #e5e5e5;
    background: #fafafa;
    -webkit-user-select: none;
    user-select: none;
    -moz-transition: border-color 0.15s;
    -o-transition: border-color 0.15s;
    -webkit-transition: border-color 0.15s;
    transition: border-color 0.15s;
}

.spf-field-group .spf-cloneable-title:active,
.spf-field-group .spf-cloneable-title:hover,
.spf-field-group .spf-cloneable-title:focus {
    border: 1px solid #bbb;
    background: #fafafa;
    outline: none;
}

.spf-field-group .spf-cloneable-helper {
    position: absolute;
    top: 12px;
    right: 10px;
    z-index: 1;
    font-size: 14px;
    line-height: 1em;
}

.spf-field-group .spf-cloneable-helper i {
    display: inline-block;
    cursor: pointer;
    padding: 5px;
    color: #999;
}

.spf-field-group .spf-cloneable-helper i:hover {
    color: #555;
}

.spf-field-group .spf-cloneable-content {
    padding: 0;
    border-top: 0;
}

.spf-field-group .spf-cloneable-title-prefix,
.spf-field-group .spf-cloneable-title-number {
    margin-right: 5px;
}

.spf-field-group .spf-cloneable-alert {
    display: none;
    margin-bottom: 5px;
    padding: 10px 20px;
    color: #a94442;
    border: 1px solid #ebccd1;
    background-color: #f2dede;
}

.spf-field-group .widget-placeholder {
    margin-bottom: 10px;
    border: 1px dashed #f1c40f;
    background-color: #fffae4;
}

.spf-field-group .spf-cloneable-header-icon {
    display: inline-block;
    text-align: center;
    font-size: 14px;
    width: 17px;
    color: #aaa;
    text-indent: 0;
    vertical-align: text-top;
}

.spf-field-group .spf-cloneable-placeholder {
    background-color: #ddd;
    margin-top: 4px;
    width: 100px;
    height: 10px;
    font-size: 10px;
    line-height: 10px;
    display: inline-block;
    vertical-align: top;
    border-radius: 2px;
}

/**
 * 03. 15. Field: icon
 */

.spf-field-icon input {
    display: none;
}

.spf-field-icon .button {
    margin-right: 5px;
}

.spf-field-icon .spf-icon-preview i {
    display: inline-block;
    font-size: 14px;
    width: 30px;
    height: 26px;
    line-height: 26px;
    margin-right: 5px;
    text-align: center;
    vertical-align: top;
    color: #555;
    border: 1px solid #ccc;
    background-color: #f7f7f7;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    border-radius: 3px;
    -moz-box-shadow: 0 1px 0 rgba(0, 0, 0, 0.08);
    -webkit-box-shadow: 0 1px 0 rgba(0, 0, 0, 0.08);
    box-shadow: 0 1px 0 rgba(0, 0, 0, 0.08);
    -moz-box-sizing: content-box;
    -webkit-box-sizing: content-box;
    box-sizing: content-box;
}

/**
 * 03. 16. Field: image_select
 */



.spf-field-image_select .spf--image{
    cursor: pointer;
    position: relative;
    display: inline-block;
    max-width: 100%;
    margin: 0 15px 5px 0;
    vertical-align: bottom;
    outline: 2px solid transparent;
    background-color: #fff;
    user-select: none;
    -webkit-user-select: none;
    -moz-transition: all 0.2s;
    -o-transition: all 0.2s;
    -webkit-transition: all 0.2s;
    transition: all 0.2s;
    outline-offset: -2px;
}


.spf-field-image_select .spf--image:before {
    position: absolute;
    top: 0;
    left: 0;
    text-align: center;
    font-size: 11px;
    font-family: FontAwesome;
    content: "\f00c";
    width: 15px;
    height: 15px;
    line-height: 15px;
    opacity: 0;
    color: #fff;
    background-color:#1EA4B0;
    transition: opacity .2s;
}

.spf-field-image_select .spf--image.spf--active:before {
    opacity: 1;
}

.spf-field-image_select .spf--active img {
    outline-color: #1EA4B0;

}
.spf-field-image_select input {
    display: none;
}

.spf-field-image_select .spf--image img {
    color: #7b8898;
    outline: solid 3px transparent;
    border-radius: 2px;
    cursor: pointer;
    text-align: center;
    width: 80px;
    outline-offset: -3px;
}

.spf-field-image_select .spf--image img {
    max-width: 100%;
}

.spf-field-image_select span {
    margin-top: 5px;
    font-weight: 500;
    text-align: center;
    margin-right: 10px;
    display: block;
    font-size: 12px;
    text-transform: capitalize;

}

.spf-field-image_select .spf--image.spf--active img {
    outline-color: #1EA4B0;
}

/* Carousel Type */

.spf-field-carousel_type .spf--image {
    cursor: pointer;
    position: relative;
    display: inline-block;
    max-width: 100%;
    margin: 0 5px 5px 0;
    vertical-align: bottom;
    border: 2px solid transparent;
    background-color: #fff;
    user-select: none;
    -webkit-user-select: none;
    -moz-transition: all 0.2s;
    -o-transition: all 0.2s;
    -webkit-transition: all 0.2s;
    transition: all 0.2s;
}


.spf-field-carousel_type input {
    display: none;
}

.spf-field-carousel_type .spf--image {
    background: #e8ecef;
    color: #7b8898;
    margin-right: 10px;
    border: solid 3px #e8ecef;
    border-radius: 2px;
    cursor: pointer;
    text-align: center;
    width: 120px;
    height: 80px;
    box-shadow: inset 0 0 0px 3px #fff;
}

.spf-field-carousel_type i {
    font-size: 30px;
    width: 32px;
    height: 30px;
    margin-top: 15px;
}

.spf-field-carousel_type p {
    margin-top: 5px;
    font-weight: 500;
}

.spf-field-carousel_type .spf--image.spf--active {
    border-color: #1EA4B0;
}

/**
 * 03. 17. Field: link_color
 */

.spf-field-link_color .spf--left {
    float: left;
    margin-right: 10px;
    margin-bottom: 5px;
}

.spf-field-link_color .spf--title {
    color: #999;
    margin-bottom: 5px;
}

/**
 * 03. 18. Field: media
 */

.spf-field-media .spf--placeholder {
    margin-bottom: 10px;
    display: flex;
}

.spf-field-media .spf--placeholder input {
    width: 100%;
}

.spf-field-media .button {
    margin-left: 7px;
}

.spf-field-media .hidden+.button {
    margin-left: 0;
}

.spf-field-media .spf--preview {
    position: relative;
}

.spf-field-media .spf--preview .fa-times {
    position: absolute;
    z-index: 1;
    right: 4px;
    top: 4px;
    font-size: 14px;
    width: 22px;
    height: 22px;
    line-height: 22px;
    text-align: center;
    text-decoration: none;
    color: #fff;
    background-color: #dd3333;
    opacity: 0.8;
    transition: all .2s;
}

.spf-field-media .spf--preview .fa-times:hover {
    opacity: 1;
}

.spf-field-media .spf--preview .fa-times:focus {
    box-shadow: none;
}

/**
 * 03. 19. Field: palette
 */

.spf-field-palette .spf--palette {
    position: relative;
    display: inline-block;
    cursor: pointer;
    border: 2px solid #ddd;
    margin-right: 10px;
    margin-bottom: 10px;
    user-select: none;
    -webkit-user-select: none;
    transition: all .2s;
}

.spf-field-palette .spf--palette span {
    vertical-align: middle;
    display: inline-block;
    width: 22px;
    height: 60px;
    line-height: 60px;
    overflow: hidden;
    text-indent: -999px;
}

.spf-field-palette .spf--palette:before {
    position: absolute;
    top: 0;
    left: 0;
    text-align: center;
    font-size: 11px;
    font-family: FontAwesome;
    content: "\f00c";
    width: 15px;
    height: 15px;
    line-height: 15px;
    opacity: 0;
    color: #fff;
    background-color: #222;
    transition: opacity .2s;
}

.spf-field-palette .spf--active {
    border-color: #222;
    box-shadow: 0 0 20px rgba(0, 0, 0, 0.2);
}

.spf-field-palette .spf--active:before {
    opacity: 1;
}

.spf-field-palette input {
    display: none;
}

/**
 * 03. 20. Field: repeater
 */

.spf-field-repeater .spf-field {
    padding: 10px;
}

.spf-field-repeater .spf-field-text input {
    width: 100%;
}

.spf-field-repeater .spf-repeater-hidden {
    display: none !important;
}

.spf-field-repeater .spf-repeater-wrapper .spf-repeater-item {
    display: table;
    width: 100%;
    margin-bottom: 5px;
    border: 1px solid #eee;
}

.spf-field-repeater .spf-repeater-wrapper .spf-repeater-item h4 {
    font-size: 1em;
}

.spf-field-repeater .spf-repeater-content {
    width: 100%;
    display: table-cell;
    vertical-align: middle;
    background-color: #fff;
}

.spf-field-repeater .spf-repeater-helper {
    width: 100%;
    display: table-cell;
    vertical-align: middle;
    text-align: center;
    font-size: 14px;
    line-height: 1em;
    border-left: 1px solid #eee;
    background-color: #f7f7f7;
}

.spf-field-repeater .spf-repeater-helper i {
    display: inline-block;
    cursor: pointer;
    color: #999;
    padding: 5px;
}

.spf-field-repeater .spf-repeater-helper i:hover {
    color: #555;
}

.spf-field-repeater .spf-repeater-helper-inner {
    width: 75px;
}

.spf-field-repeater .spf-repeater-alert {
    display: none;
    margin-bottom: 5px;
    padding: 10px 20px;
    color: #a94442;
    border: 1px solid #ebccd1;
    background-color: #f2dede;
}

.spf-field-repeater .widget-placeholder {
    height: 50px;
    margin-bottom: 3px;
    border: 1px dashed #f1c40f;
    background-color: #fffae4;
}

.spf-field-repeater .ui-sortable-helper {
    height: 50px !important;
    overflow: hidden !important;
    border-color: #ccc !important;
    background-color: #eee !important;
    opacity: 0.5;
}

.spf-field-repeater .ui-sortable-helper .spf-repeater-helper,
.spf-field-repeater .ui-sortable-helper .spf-repeater-content {
    display: none;
}

/**
 * 03. 21. Field: select
 */

.spf-field-select select {
    max-width: 100%;
}

/**
 * 03. 22. Field: slider
 */

.spf-field-slider em {
    padding-left: 5px;
    color: #aaa;
}

.spf-field-slider input[type="text"] {
    width: 45px;
    margin-left: 15px;
    text-align: center;
}

.spf-field-slider .ui-slider {
    position: relative;
    width: 100%;
    height: 4px;
    border: none;
    background: #ddd;
    border-radius: 2px;
}

.spf-field-slider .ui-slider-range {
    height: 4px;
    border: none;
    background: #222;
    border-radius: 2px;
}

.spf-field-slider .ui-slider-handle {
    position: absolute;
    width: 18px;
    height: 18px;
    top: -7px;
    margin-left: -8px;
    border: none;
    background: #222;
    border-radius: 2px;
}

.spf-field-slider .ui-state-active,
.spf-field-slider .ui-slider-handle:hover {
    cursor: pointer;
    background: #444;
}

/**
 * 03. 23. Field: sortable
 */

.spf-field-sortable .spf-field {
    padding: 10px;
}

.spf-field-sortable .spf-field-text input {
    width: 100%;
    max-width: 100%;
}

.spf-field-sortable .spf--sortable .spf--sortable-item {
    display: table;
    width: 100%;
    margin-bottom: 5px;
    border: 1px solid #eee;
}

.spf-field-sortable .spf--sortable .spf--sortable-item h4 {
    font-size: 1em;
}

.spf-field-sortable .spf--sortable-content {
    width: 100%;
    display: table-cell;
    vertical-align: middle;
    background-color: #fff;
}

.spf-field-sortable .spf--sortable-helper {
    width: 100%;
    display: table-cell;
    vertical-align: middle;
    text-align: center;
    font-size: 14px;
    line-height: 1em;
    border-left: 1px solid #eee;
    background-color: #f7f7f7;
}

.spf-field-sortable .spf--sortable-helper .fa {
    display: inline-block;
    cursor: pointer;
    width: 50px;
    color: #555;
}

.spf-field-sortable .spf--sortable-helper .fa:hover {
    opacity: 0.5;
}

.spf-field-sortable .widget-placeholder {
    height: 50px;
    margin-bottom: 3px;
    border: 1px dashed #f1c40f;
    background-color: #fffae4;
}

.spf-field-sortable .ui-sortable-helper {
    height: 50px !important;
    overflow: hidden !important;
    border-color: #ccc !important;
    background-color: #eee !important;
    opacity: 0.5;
}

.spf-field-sortable .ui-sortable-helper .spf--sortable-helper,
.spf-field-sortable .ui-sortable-helper .spf--sortable-content {
    display: none;
}

/**
 * 03. 24. Field: sorter
 */

.spf-field-sorter .ui-sortable-placeholder {
    height: 20px;
    border: 1px dashed #f1c40f;
    background-color: #fffae4;
}

.spf-field-sorter .spf-modules {
    float: left;
    width: 50%;
    box-sizing: border-box;
}

.spf-field-sorter .spf-modules:first-child {
    padding-right: 15px;
}

.spf-field-sorter .spf-modules:last-child {
    padding-left: 15px;
}

.spf-field-sorter .spf-disabled,
.spf-field-sorter .spf-enabled {
    padding: 5px 15px;
    border: 1px dashed #ddd;
    background-color: #fff;
}

.spf-field-sorter .spf-disabled li {
    -moz-transition: opacity 0.15s;
    -o-transition: opacity 0.15s;
    -webkit-transition: opacity 0.15s;
    transition: opacity 0.15s;
    opacity: 0.5;
}

.spf-field-sorter .spf-disabled .ui-sortable-helper {
    opacity: 1;
}

.spf-field-sorter .spf-sorter-title {
    font-size: 13px;
    font-weight: 600;
    padding: 10px;
    text-align: center;
    border: 1px dashed #ddd;
    border-bottom: none;
    background-color: #f8f8f8;
    text-transform: uppercase;
}

.spf-field-sorter ul {
    list-style-type: none;
    margin: 0;
    padding: 0;
    min-height: 62px;
}

.spf-field-sorter ul li {
    margin: 10px 0;
    padding: 10px 15px;
    cursor: move;
    font-weight: bold;
    text-align: center;
    border: 1px solid #e5e5e5;
    background-color: #fafafa;
    -moz-transition: border-color 0.15s;
    -o-transition: border-color 0.15s;
    -webkit-transition: border-color 0.15s;
    transition: border-color 0.15s;
}

.spf-field-sorter ul li:hover {
    border-color: #bbb;
}

/**
 * 03. 25. Field: spinner
 */

.spf-field-spinner .spf--spin {
    float: left;
}

.spf-field-spinner .spf--unit {
    float: right;
    height: 30px;
    line-height: 26px;
    text-align: center;
    border-left: none;
    color: #999;
    border: 1px solid #ddd;
    border-left: 0;
    background-color: #eee;
    padding: 0 6px;
    margin: 0;
    box-sizing: border-box;
}

.spf-field-spinner .ui-spinner-button {
    cursor: pointer;
    position: relative;
    overflow: hidden;
    margin: 0;
    padding: 0;
    width: 30px;
    height: 30px;
    line-height: 30px;
    text-align: center;
    border: 1px solid #ddd;
    color: #555;
    background-color: #eee;
    box-sizing: border-box;
}

.spf-field-spinner .ui-spinner-button:hover {
    background-color: #e7e7e7;
}

.spf-field-spinner .ui-spinner-button:active {
    background-color: #ddd;
}

.spf-field-spinner .ui-spinner-button:before {
    font-family: FontAwesome;
    font-size: 16px;
    line-height: 16px;
}

.spf-field-spinner .ui-spinner-down {
    float: left;
    border-right: 0;
    border-radius: 2px 0 0 2px;
}

.spf-field-spinner .ui-spinner-down:before {
    content: "\f0d9";
}

.spf-field-spinner .ui-spinner-up {
    float: right;
    border-left: 0;
    border-radius: 0 2px 2px 0;
}

.spf-field-spinner .ui-spinner-up:before {
    content: "\f0da";
}

.spf-field-spinner input {
    width: 50px;
    text-align: center;
    margin: 0;
    padding: 0 8px;
    height: 30px;
    line-height: 30px;
    border: 1px solid #ddd;
}

.spf-field-spinner input:focus {
    outline: none;
}

.spf-field-spinner .ui-button-text {
    display: none;
}

/**
 * 03. 26. Field: switcher, switcherf
 */

.spf-field-switcher .spf--switcher,
.spf-field-switcherf .spf--switcher {
    float: left;
    cursor: pointer;
    position: relative;
    width: 60px;
    height: 26px;
    padding: 0;
    margin: 0;
    overflow: hidden;
    border-radius: 4px;
    background-color: #ed6f6f;
    user-select: none;
    -webkit-user-select: none;
}

.spf-field-switcherf .spf--ball,
.spf-field-switcher .spf--ball {
    position: absolute;
    top: 4px;
    left: 4px;
    width: 24px;
    height: 18px;
    background-color: #fff;
    border-radius: 4px;
    transition: all .1s;
    box-shadow: 1px 1px 1px rgba(0, 0, 0, 0.15);
}

.spf-field-switcherf .spf--on,
.spf-field-switcherf .spf--off,
.spf-field-switcher .spf--on,
.spf-field-switcher .spf--off {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    font-size: 11px;
    line-height: 26px;
    font-weight: 500;
    font-style: normal;
    text-align: center;
    text-transform: uppercase;
    color: #fff;
    padding-right: 28px;
    opacity: 0;
    transition: all .1s;
}

.spf-field-switcherf .spf--off,
.spf-field-switcher .spf--off {
    padding-right: 0;
    padding-left: 28px;
    opacity: 1;
}

/* .spf-field-switcherf .spf--active, */
.spf-field-switcher .spf--active {
    background: #4fb845;
}

.spf-field-switcherf .spf--active .spf--on,
.spf-field-switcher .spf--active .spf--on {
    opacity: 1;
}

.spf-field-switcherf .spf--active .spf--off,
.spf-field-switcher .spf--active .spf--off {
    opacity: 0;
}

.spf-field-switcherf .spf--active .spf--ball,
.spf-field-switcher .spf--active .spf--ball {
    left: 100%;
    margin-left: -28px;
}

.spf-field-switcherf .spf--label,
.spf-field-switcher .spf--label {
    float: left;
    margin-top: 4px;
    margin-left: 8px;
    font-weight: 400;
    color: #999;
}

.spf-field-switcherf input,
.spf-field-switcher input {
    display: none;
}

/**
 * 03. 27. Field: tabbed
 */

.spf-field-tabbed .spf-tabbed-section {
    border: 1px solid #eee;
    background: #fff;
}

.spf-field-tabbed .spf-tabbed-nav .spf--icon {
    padding-right: 5px;
}

.spf-field-tabbed .spf-tabbed-nav a {
    display: inline-block;
    padding: 12px 15px;
    margin-top: 1px;
    margin-right: 5px;
    margin-bottom: -1px;
    position: relative;
    text-decoration: none;
    color: #444;
    font-weight: 600;
    background-color: #f3f3f3;
    border: 1px solid #eee;
    -moz-transition: all 0.2s;
    -o-transition: all 0.2s;
    -webkit-transition: all 0.2s;
    transition: all 0.2s;
}

.spf-field-tabbed .spf-tabbed-nav a:hover {
    background-color: #f9f9f9;
}

.spf-field-tabbed .spf-tabbed-nav a.spf-tabbed-active {
    background-color: #fff;
    border-bottom-color: #fff;
}

.spf-field-tabbed .spf-tabbed-nav a:focus {
    -moz-box-shadow: none;
    -webkit-box-shadow: none;
    box-shadow: none;
}

/**
 * 03. 28. Field: text
 */

.spf-field-text input {
    width: 340px;
    max-width: 100%;
}

/**
 * 03. 29. Field: textarea
 */

.spf-field-textarea textarea {
    width: 100%;
    max-width: 100%;
    min-height: 125px;
}

.spf-field-textarea .spf-shortcode-button {
    margin-bottom: 10px;
    margin-right: 5px;
}

/**
 * 03. 30. Field: typography
 */

.spf-field-typography textarea,
.spf-field-typography select {
    margin: 0;
    width: 100%;
}

.spf-field-typography .spf--title {
    color: #999;
    margin: 0 0 2px 0;
}

.spf-field-typography .spf--title small {
    vertical-align: top;
}

.spf-field-typography .spf--blocks {
    display: flex;
    flex-wrap: wrap;
}

.spf-field-typography .spf--block {
    padding-right: 5px;
    padding-bottom: 10px;
    box-sizing: border-box;
}

.spf-field-typography .spf--block .spf--block {
    padding-right: 0;
    padding-bottom: 0;
}

.spf-field-typography .spf--blocks-selects .spf--block {
    flex: 1 33.3%;
}

.spf-field-typography .spf--blocks-inputs .spf--block {
    flex: 1 25%;
}

.spf-field-typography .spf--blocks-inputs .spf--block .spf--block {
    flex: 1;
}

.spf-field-typography .spf--input {
    margin: 0;
    width: 100%;
    border-radius: 4px 0 0 4px;
}

.spf-field-typography .spf--unit {
    min-width: 40px;
    max-width: 40px;
    padding: 4px 0;
    font-size: 12px;
    font-weight: 400;
    text-align: center;
    color: #777;
    border: 1px solid #ddd;
    background-color: #eee;
    border-radius: 0 2px 2px 0;
    border-left: 0;
}

.spf-field-typography .spf--preview {
    font-size: 16px;
    line-height: 20px;
    padding: 20px;
    color: #222;
    border: 1px solid #eee;
    background-color: #fff;
    border-radius: 2.5px;
    user-select: none;
    -webkit-user-select: none;
    transition: background-color .2s, border-color .2s;
}

.spf-field-typography .spf--block-preview {
    cursor: pointer;
    position: relative;
    overflow: hidden;
    margin-top: 10px;
    max-width: 100%;
}

.spf-field-typography .spf--black-background {
    border-color: #000;
    background-color: #000;
}

.spf-field-typography .spf--toggle {
    position: absolute;
    top: 5px;
    right: 10px;
    color: #999;
}

.spf-field-typography .spf--block-extra-styles {
    margin-top: 5px;
}

/**
 * 03. 31. Field: upload
 */

.spf-field-upload input {
    width: 100%;
}

.spf-field-upload .spf--wrap {
    display: flex;
}

.spf-field-upload .spf--buttons {
    display: flex;
    margin-left: 5px;
}

.spf-field-upload .spf--remove {
    margin-left: 5px;
}

/**
 * 03. 32. Field: wp_editor
 */

.spf-field-wp_editor .spf-wp-editor {
    float: left;
    width: 100%;
}

.spf-field-wp_editor .mce-toolbar-grp {
    border: none;
}

.spf-field-wp_editor .mce-btn.mce-active button,
.spf-field-wp_editor .mce-btn.mce-active:hover button,
.spf-field-wp_editor .mce-btn.mce-active i,
.spf-field-wp_editor .mce-btn.mce-active:hover i {
    color: #23282d;
}

.spf-field-wp_editor .wp-media-buttons {
    position: relative;
    z-index: 2;
}

.spf-field-wp_editor .wp-editor-tabs {
    position: relative;
    z-index: 1;
}

.spf-field-wp_editor .spf-no-tinymce {
    border: 1px solid #e5e5e5;
}

.spf-field-wp_editor .spf-no-quicktags .wp-media-buttons {
    float: none;
    display: block;
}

.spf-field-wp_editor .spf-no-quicktags .mce-tinymce {
    box-shadow: none;
    border: 1px solid #e5e5e5;
}

.spf-field-wp_editor textarea {
    width: 100%;
    max-width: 100%;
    margin: 0;
    box-shadow: none;
}

/**
 * 03. 33. Field: heading
 */

.spf-field-heading {
    font-size: 1.5em;
    font-weight: bold;
    color: #23282d;
    background-color: #f5f5f5;
}

/**
 * 03. 34. Field: subheading
 */

.spf-field-subheading {
    font-size: 14px;
    font-weight: bold;
    padding-top: 17px;
    padding-bottom: 17px;
    color: #23282d;
    background-color: #f7f7f7;
}

/**
 * 03. 35. Field: submessage
 */

.spf-field-submessage {
    padding: 0 !important;
    border: 0 !important;
}

.spf-field-submessage+.spf-field {
    border-top: 0 !important;
}

.spf-submessage {
    font-size: 12px;
    padding: 17px 30px;
    border-top: 1px solid transparent;
    border-bottom: 1px solid transparent;
}

.spf-submessage-success {
    color: #3c763d;
    border-color: #d6e9c6;
    background-color: #dff0d8;
}

.spf-submessage-info {
    color: #31708f;
    border-color: #bce8f1;
    background-color: #d9edf7;
}

.spf-submessage-warning {
    color: #8a6d3b;
    border-color: #faebcc;
    background-color: #fcf8e3;
}

.spf-submessage-danger {
    color: #a94442;
    border-color: #ebccd1;
    background-color: #f2dede;
}

.spf-submessage-normal {
    color: #23282d;
    border-color: #eee;
    background-color: #f7f7f7;
}

/**
 * 03. 36. Field: notice
 */

.spf-field-notice {
    background-color: #f7f7f7;
}

.spf-notice-success {
    border-color: #46b450;
}

.spf-notice-info {
    border-color: #339fd4;
}

.spf-notice-warning {
    border-color: #ffbc00;
}

.spf-notice-danger {
    border-color: #dc3232;
}

/**
 * 03. 37. others
 */

.spf-help {
    cursor: help;
    position: absolute;
    top: 0;
    right: 0;
    padding: 5px;
    font-size: 14px;
    color: #aaa;
}

.spf-help .spf-help-text {
    display: none;
}

.spf-image-preview {
    display: inline-block;
    position: relative;
    padding: 4px;
    min-width: 44px;
    min-height: 22px;
    margin-bottom: 10px;
    border: 1px solid #ccc;
    background-color: #f9f9f9;
    -moz-box-shadow: 0 1px 0 rgba(0, 0, 0, 0.08);
    -webkit-box-shadow: 0 1px 0 rgba(0, 0, 0, 0.08);
    box-shadow: 0 1px 0 rgba(0, 0, 0, 0.08);
}

.spf-image-preview img {
    max-height: 90px;
    display: inline-block;
    vertical-align: middle;
}

.spf-field-custom .spf-field {
    padding: 0;
}

.spf-field .chosen-container-single .chosen-single {
    height: 28px;
    line-height: 26px;
}

.spf-field .chosen-container-single .chosen-single abbr {
    top: 0;
    right: 20px;
    font-family: FontAwesome;
    font-size: 12px;
    height: 100%;
    width: 18px;
    color: #aaa;
    text-align: center;
    background: none;
}

.spf-field .chosen-container-single .chosen-single abbr:before {
    content: "\f00d";
}

.spf-field .chosen-container-single .chosen-single abbr:hover {
    color: #555;
}

.spf-field .chosen-container-multi .chosen-choices li.search-choice .search-choice-close {
    font-family: FontAwesome;
    font-size: 12px;
    height: 100%;
    width: 18px;
    color: #aaa;
    text-align: center;
    background: none;
}

.spf-field .chosen-container-multi .chosen-choices li.search-choice .search-choice-close:before {
    content: "\f00d";
}

.spf-field .chosen-container-multi .chosen-choices li.search-choice .search-choice-close:hover {
    color: #555;
}

.spf-field .chosen-container-single .chosen-single div b {
    font-family: FontAwesome;
    font-size: 14px;
    color: #aaa;
    background: none;
}

.spf-field .chosen-container-single .chosen-single div b:before {
    content: "\f107";
}

.spf-field .chosen-container-single .chosen-single div b:hover {
    color: #555;
}

.spf-field .chosen-container-active.chosen-with-drop .chosen-single div b:before {
    content: "\f106";
}

.spf-field .chosen-container-single .chosen-single-with-deselect span {
    margin-right: 40px;
}

.spf-field .chosen-container-single .chosen-search input[type="text"] {
    background: none;
}

.spf-field .chosen-container-single .chosen-search:before {
    font-family: FontAwesome;
    position: absolute;
    content: "\f002";
    font-size: 11px;
    right: 10px;
    top: 7px;
    color: #aaa;
}

.spf-field .wp-picker-container {
    display: inline-block;
}

.spf-field .spf--transparent-wrap {
    display: none;
    position: relative;
    top: -1px;
    width: 235px;
    padding: 9px 10px;
    border: 1px solid #dfdfdf;
    border-top: none;
    background-color: #fff;
}

.spf-field .spf--transparent-slider {
    position: absolute;
    width: 190px;
    margin-left: 2px;
    height: 18px;
}

.spf-field .spf--transparent-slider .ui-slider-handle {
    position: absolute;
    top: -3px;
    bottom: -3px;
    z-index: 5;
    border-color: #aaa;
    border-style: solid;
    border-width: 4px 3px;
    width: 10px;
    height: 16px;
    margin: 0 -5px;
    background: none;
    cursor: ew-resize;
    opacity: 0.9;
    -moz-border-radius: 4px;
    -webkit-border-radius: 4px;
    border-radius: 4px;
    -moz-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2);
    -webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2);
    box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2);
}

.spf-field .spf--transparent-slider .ui-slider-handle:before {
    content: " ";
    position: absolute;
    left: -2px;
    right: -2px;
    top: -3px;
    bottom: -3px;
    border: 2px solid #fff;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    border-radius: 3px;
}

.spf-field .spf--transparent-offset {
    height: 18px;
    width: 200px;
    background: url(../images/checkerboard.png) repeat-y center left scroll #fff;
    -moz-box-shadow: 0 0 5px rgba(0, 0, 0, 0.4) inset;
    -webkit-box-shadow: 0 0 5px rgba(0, 0, 0, 0.4) inset;
    box-shadow: 0 0 5px rgba(0, 0, 0, 0.4) inset;
    -moz-border-radius: 2px;
    -webkit-border-radius: 2px;
    border-radius: 2px;
}

.spf-field .spf--transparent-text {
    position: absolute;
    top: 12px;
    right: 10px;
    width: 30px;
    font-size: 12px;
    line-height: 12px;
    text-align: center;
    color: #999;
}

.spf-field .spf--transparent-button {
    display: inline-block;
    text-align: center;
    cursor: pointer;
    margin-top: 10px;
    user-select: none;
    -webkit-user-select: none;
    color: #999;
    transition: background-color .2s, border-color .2s, color .2s;
}

.spf-field .spf--transparent-active .wp-color-result {
    background-image: url(../images/checkerboard.png);
    background-size: 130%;
    background-position: center left;
    background-color: transparent !important;
}

.spf-field .spf--transparent-active .spf--transparent-button {
    color: #fff;
    border-color: #4fb845;
    background-color: #4fb845;
}

/**
 * 04. Widget
 */

.spf-widgets>.spf-field {
    position: relative;
    top: -1px;
    margin-right: -15px;
    margin-left: -15px;
    padding: 12px 15px;
}

.spf-widgets>.spf-field .spf-field {
    margin-left: 0;
    margin-right: 0;
}

.spf-widgets>.spf-field .spf-title {
    float: none;
    width: 100%;
    margin-bottom: 5px;
}

.spf-widgets>.spf-field .spf-fieldset {
    margin-left: 0;
}

.spf-widgets .spf-field-text input {
    width: 100%;
}

.spf-widgets .spf-field-notice .spf-notice {
    padding: 15px;
}

.control-section .spf-widgets>.spf-field {
    margin-right: -10px;
    margin-left: -10px;
    padding: 10px 12px;
}

/**
 * 05. Widget
 */

.control-section .spf-field {
    padding: 0;
}

.control-section .spf-field .spf-title {
    float: none;
    width: 100%;
    margin-bottom: 10px;
}

.control-section .spf-field .spf-title h4 {
    font-size: 14px;
    font-weight: 600;
    color: inherit;
}

.control-section .spf-field .spf-fieldset {
    margin-left: 0;
}

.control-section .spf-field-select select {
    width: 100%;
}

.control-section .spf-field-heading {
    color: inherit;
    font-size: 14px;
    line-height: 1em;
    margin-right: -15px;
    margin-left: -15px;
    padding: 15px;
}

.control-section .spf-field-subheading {
    color: inherit;
    font-size: 11px;
    margin-right: -15px;
    margin-left: -15px;
    padding: 10px 15px;
}

.control-section .spf-text-subtitle {
    margin-top: 4px;
    font-size: 12px;
}

.control-section .spf-field-content,
.control-section .spf-field-submessage .spf-submessage {
    margin-right: -15px;
    margin-left: -15px;
    padding: 15px;
}

.control-section .spf-fieldset .spf-field-submessage .spf-submessage,
.control-section .spf-fieldset .spf-field-heading,
.control-section .spf-fieldset .spf-field-subheading {
    margin-left: 0;
    margin-right: 0;
}

.control-section .spf-field-date .spf--to {
    margin-left: 0;
}

.control-section .spf-field-sorter ul li {
    padding: 5px;
}

.control-section .spf-field-sorter .spf-modules {
    float: none;
    width: 100%;
}

.control-section .spf-field-sorter .spf-modules:first-child {
    padding-right: 0;
    padding-bottom: 15px;
}

.control-section .spf-field-background_adv .spf--select,
.control-section .spf-field-background .spf--select {
    width: 100%;
}

.control-section .spf-field-border select,
.control-section .spf-field-spacing select,
.control-section .spf-field-column select,
.control-section .spf-field-dimensions select,
.control-section .spf-field-dimensions_advanced select {
    width: auto;
}

.control-section .spf-field-spinner input {
    width: 50px;
}

.control-section .spf-field-backup .spf-export-data {
    display: none;
}

.control-section .spf-field-fieldset .spf-fieldset-content {
    border-color: #e5e5e5;
}

.control-section .spf-field-fieldset .spf-field {
    padding: 10px;
}

.control-section .spf-field-fieldset .spf-field .spf-title {
    margin-bottom: 5px;
}

.control-section .spf-field-fieldset .spf-field h4 {
    font-size: 12px;
}

.control-section .spf-field-group .spf-field,
.control-section .spf-field-tabbed .spf-field,
.control-section .spf-field-sortable .spf-field,
.control-section .spf-field-repeater .spf-field,
.control-section .spf-field-accordion .spf-field {
    padding: 10px;
}

.control-section .spf-field-group .spf-field .spf-title,
.control-section .spf-field-tabbed .spf-field .spf-title,
.control-section .spf-field-sortable .spf-field .spf-title,
.control-section .spf-field-repeater .spf-field .spf-title,
.control-section .spf-field-accordion .spf-field .spf-title {
    margin-bottom: 5px;
}

.control-section .spf-field-group .spf-field h4,
.control-section .spf-field-tabbed .spf-field h4,
.control-section .spf-field-sortable .spf-field h4,
.control-section .spf-field-repeater .spf-field h4,
.control-section .spf-field-accordion .spf-field h4 {
    font-size: 12px;
}

.control-section .spf-dependency-control.hidden {
    display: none !important;
}

/**
 * 06. Taxonomy
 */

.spf-taxonomy>.spf-field {
    border-top: none !important;
}

.spf-taxonomy>.spf-field-heading {
    font-size: 1.1em;
    padding: 20px !important;
    border: 1px solid #ddd;
}

.spf-taxonomy>.spf-field-subheading {
    font-size: 12px;
    padding: 15px !important;
    border: 1px solid #ddd;
}

.spf-taxonomy>.spf-field-submessage .spf-submessage {
    padding: 15px;
    border-left-width: 1px;
    border-left-style: solid;
    border-right-width: 1px;
    border-right-style: solid;
}

.spf-taxonomy>.spf-field-notice {
    background-color: transparent;
}

.spf-taxonomy .spf-section-title {
    display: block;
    padding: 15px;
    background-color: #f9f9f9;
    border: 1px solid #e5e5e5;
    -moz-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04);
    -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04);
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04);
}

.spf-taxonomy-add-fields>.spf-field {
    padding: 8px 0;
}

.spf-taxonomy-add-fields>.spf-field>.spf-title {
    float: none;
    width: 100%;
    padding: 2px 2px 4px 0;
}

.spf-taxonomy-add-fields>.spf-field>.spf-title h4 {
    font-size: 12px;
    font-weight: normal;
}

.spf-taxonomy-add-fields>.spf-field>.spf-fieldset {
    margin-left: 0;
}

.spf-taxonomy-add-fields>.spf-field>.spf-fieldset>.spf-help {
    right: -5px;
}

.spf-taxonomy-add-fields+p.submit {
    margin-top: 0;
}

.spf-taxonomy-edit-fields>.spf-field {
    padding: 20px 0;
}

.spf-taxonomy-edit-fields>.spf-field>.spf-title {
    width: 225px;
}

.spf-taxonomy-edit-fields>.spf-field>.spf-title h4 {
    font-size: 14px;
    font-weight: 600;
    line-height: 1.3;
    display: inline-block;
    vertical-align: middle;
}

.spf-taxonomy-edit-fields>.spf-field>.spf-fieldset {
    margin-left: 225px;
}

.spf-taxonomy-edit-fields>.spf-field>.spf-fieldset>.spf-help {
    top: -5px;
    right: -5px;
}

.spf-taxonomy-edit-fields>.spf-field-submessage {
    margin: 20px 0;
}

.spf-taxonomy-edit-fields>.spf-field-subheading,
.spf-taxonomy-edit-fields>.spf-field-heading {
    margin: 20px 0;
    border: 1px solid #ddd;
}

/**
 * 07. Profile
 */

.spf-profile>h2>.fa {
    padding-right: 7px;
}

.spf-profile>.spf-field {
    padding: 15px 0;
    border-top: none !important;
}

.spf-profile>.spf-field>.spf-title {
    width: 220px;
}

.spf-profile>.spf-field>.spf-title h4 {
    font-size: 14px;
    font-weight: 600;
    line-height: 1.3;
    display: inline-block;
    vertical-align: middle;
}

.spf-profile>.spf-field>.spf-fieldset {
    margin-left: 220px;
}

.spf-profile>.spf-field>.spf-fieldset>.spf-help {
    top: -15px;
    right: -5px;
}

.spf-profile>.spf-field-heading {
    font-size: 1.1em;
}

.spf-profile>.spf-field-subheading {
    font-size: 12px;
}

.spf-profile>.spf-field-subheading,
.spf-profile>.spf-field-heading {
    margin: 10px 0;
    padding: 15px !important;
    border: 1px solid #ddd;
}

.spf-profile>.spf-field-submessage {
    margin: 20px 0;
}

.spf-profile>.spf-field-submessage .spf-submessage {
    padding: 10px;
    border-left-width: 1px;
    border-left-style: solid;
    border-right-width: 1px;
    border-right-style: solid;
}

.spf-profile>.spf-field-notice {
    background-color: transparent;
}

/**
 * 08. Modal
 */

.spf-modal {
    display: none;
    position: fixed;
    z-index: 100101;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
}

.spf-modal-icon {
    z-index: 100102;
}

.spf-modal-table {
    display: table;
    width: 100%;
    height: 100%;
}

.spf-modal-table-cell {
    display: table-cell;
    vertical-align: middle;
    margin: 100px 0;
}

.spf-modal-inner {
    position: relative;
    z-index: 10;
    width: 760px;
    height: 750px;
    margin: 0 auto;
    background-color: #fff;
}

.spf-modal-content {
    position: relative;
    overflow: hidden;
    overflow-y: auto;
    height: 592px;
}

.spf-modal-content .spf-shortcode-button {
    display: none;
}

.spf-modal-content .spf-fieldset {
    margin-left: 25%;
}

.spf-modal-content .spf-title {
    width: 20%;
}

.spf-modal-content .spf-field {
    padding: 15px 30px 15px 15px;
}

.spf-modal-content a:active,
.spf-modal-content a:focus {
    outline: none;
    -moz-box-shadow: none;
    -webkit-box-shadow: none;
    box-shadow: none;
}

.spf-modal-content h4 {
    font-size: 13px;
}

.spf-modal-content h4 small {
    font-style: italic;
    font-weight: 400;
    color: #aaa;
}

.spf-modal-title {
    position: relative;
    background-color: #fcfcfc;
    border-bottom: 1px solid #ddd;
    height: 36px;
    font-size: 16px;
    font-weight: 600;
    line-height: 36px;
    margin: 0;
    padding: 0 36px 0 16px;
}

.spf-modal-header {
    width: 100%;
    padding: 16px 0;
    background-color: #f5f5f5;
    border-bottom: 1px solid #eee;
}

.spf-modal-header select {
    display: block;
    width: 250px;
    margin: 0 auto;
    background-color: #fff;
}

.spf-modal-close {
    color: #666;
    padding: 0;
    position: absolute;
    top: 0;
    right: 0;
    width: 36px;
    height: 36px;
    text-align: center;
    background: none;
    border: none;
    cursor: pointer;
}

.spf-modal-close:before {
    font: normal 20px/36px dashicons;
    content: "\f158";
    vertical-align: top;
    width: 36px;
    height: 36px;
}

.spf-modal-close:hover {
    opacity: 0.5;
}

.spf-modal-insert-wrapper {
    text-align: center;
    width: 100%;
    padding: 16px 0;
    background-color: #f5f5f5;
    border-top: 1px solid #eee;
}

.spf-modal-overlay {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background-color: #000;
    opacity: 0.5;
}

/**
 * 08. 01. Shortcode Modal
 */

.spf--repeatable {
    padding: 15px 15px 0 15px;
}

.spf--repeat-button-block {
    text-align: center;
    padding-bottom: 15px;
}

.spf--repeat-shortcode {
    position: relative;
    margin-bottom: 15px;
    border: 1px dashed #ddd;
}

.spf--repeat-shortcode:first-child .spf-repeat-remove {
    display: none;
}

.spf--repeat-shortcode .spf-repeat-remove {
    position: absolute;
    right: 10px;
    top: 10px;
    z-index: 10;
    cursor: pointer;
    display: inline-block;
    font-size: 11px;
    width: 18px;
    height: 18px;
    line-height: 18px;
    text-align: center;
    border-radius: 2px;
    color: #fff;
    background-color: #e14d43;
    opacity: 0.5;
}

.spf--repeat-shortcode .spf-repeat-remove:hover {
    opacity: 1;
}

.spf-shortcode-single .spf-modal-inner {
    height: 750px;
}

.spf-shortcode-single .spf-modal-content {
    height: 652px;
}

.elementor-editor-active .spf-shortcode-button {
    margin-left: 5px;
}

.elementor-editor-active .spf-modal .hidden {
    display: none !important;
}

/**
 * 08. 03. Icon Modal
 */

.spf-modal-icon .spf-icon-title {
    padding: 15px 0;
    margin: 4px;
    font-size: 14px;
    font-weight: bold;
    text-align: center;
    border: 1px solid #eee;
    background-color: #f7f7f7;
}

.spf-modal-icon .spf-icon-search {
    width: 250px;
    height: 40px;
    line-height: 40px;
}

.spf-modal-icon a {
    display: inline-block;
    padding: 4px;
    cursor: pointer;
}

.spf-modal-icon a .spf-icon {
    position: relative;
    padding: 4px;
    display: inline-block;
    font-size: 14px;
    width: 30px;
    height: 26px;
    line-height: 26px;
    text-align: center;
    vertical-align: top;
    color: #555;
    border: 1px solid #ccc;
    background-color: #f7f7f7;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    border-radius: 3px;
    -moz-box-shadow: 0 1px 0 rgba(0, 0, 0, 0.08);
    -webkit-box-shadow: 0 1px 0 rgba(0, 0, 0, 0.08);
    box-shadow: 0 1px 0 rgba(0, 0, 0, 0.08);
    -moz-box-sizing: content-box;
    -webkit-box-sizing: content-box;
    box-sizing: content-box;
}

.spf-modal-icon a:hover .spf-icon {
    color: #fff;
    border-color: #222;
    background-color: #222;
}

.spf-modal-icon .spf-modal-content {
    padding: 10px;
    height: 618px;
}

.spf-modal-icon .spf-text-error {
    padding: 10px;
}

.spf-modal-loading {
    display: none;
    position: absolute;
    left: 15px;
    top: 15px;
}

.spf-loading {
    position: relative;
    width: 20px;
    height: 20px;
    background: #ccc;
    -moz-border-radius: 20px;
    -webkit-border-radius: 20px;
    border-radius: 20px;
    -moz-box-shadow: 0 2px 5px rgba(0, 0, 0, 0.07);
    -webkit-box-shadow: 0 2px 5px rgba(0, 0, 0, 0.07);
    box-shadow: 0 2px 5px rgba(0, 0, 0, 0.07);
}

.spf-loading:after {
    position: absolute;
    top: 50%;
    left: 50%;
    width: 4px;
    height: 4px;
    content: "";
    margin-top: -2px;
    margin-left: -2px;
    background-color: white;
    -moz-animation-duration: 0.5s;
    -webkit-animation-duration: 0.5s;
    animation-duration: 0.5s;
    -moz-animation-iteration-count: infinite;
    -webkit-animation-iteration-count: infinite;
    animation-iteration-count: infinite;
    -moz-animation-timing-function: linear;
    -webkit-animation-timing-function: linear;
    animation-timing-function: linear;
    -moz-animation-name: csfLoader;
    -webkit-animation-name: csfLoader;
    animation-name: csfLoader;
    -moz-border-radius: 4px;
    -webkit-border-radius: 4px;
    border-radius: 4px;
}

@-moz-keyframes csfLoader {
    0% {
        -moz-transform: rotate(0deg) translateX(-6px) rotate(0deg);
        transform: rotate(0deg) translateX(-6px) rotate(0deg);
    }

    100% {
        -moz-transform: rotate(360deg) translateX(-6px) rotate(-360deg);
        transform: rotate(360deg) translateX(-6px) rotate(-360deg);
    }
}

@-webkit-keyframes csfLoader {
    0% {
        -webkit-transform: rotate(0deg) translateX(-6px) rotate(0deg);
        transform: rotate(0deg) translateX(-6px) rotate(0deg);
    }

    100% {
        -webkit-transform: rotate(360deg) translateX(-6px) rotate(-360deg);
        transform: rotate(360deg) translateX(-6px) rotate(-360deg);
    }
}

@keyframes csfLoader {
    0% {
        -moz-transform: rotate(0deg) translateX(-6px) rotate(0deg);
        -ms-transform: rotate(0deg) translateX(-6px) rotate(0deg);
        -webkit-transform: rotate(0deg) translateX(-6px) rotate(0deg);
        transform: rotate(0deg) translateX(-6px) rotate(0deg);
    }

    100% {
        -moz-transform: rotate(360deg) translateX(-6px) rotate(-360deg);
        -ms-transform: rotate(360deg) translateX(-6px) rotate(-360deg);
        -webkit-transform: rotate(360deg) translateX(-6px) rotate(-360deg);
        transform: rotate(360deg) translateX(-6px) rotate(-360deg);
    }
}

/**
 * 09. Helper
 */

.spf-text-desc,
.spf-text-subtitle {
    font-weight: 400;
    font-style: italic;
    margin-top: 4px;
    color: #999;
}

.spf-text-success {
    color: #2b542c;
}

.spf-text-error {
    color: #d02c21;
}

.spf-text-info {
    color: #31708f;
}

.spf-text-warning {
    color: #ffb900;
}

.spf-text-muted {
    color: #aaa;
}

.spf-text-left {
    text-align: left;
}

.spf-text-center {
    text-align: center;
}

.spf-text-right {
    text-align: right;
}

.spf-block-left {
    float: left;
}

.spf-block-right {
    float: right;
}

.spf-full-width {
    width: 100%;
}

.spf-full-half {
    width: 50%;
}

.spf-table {
    width: 100%;
    display: table;
}

.spf-table-cell {
    display: table-cell;
    vertical-align: middle;
}

.spf-table-expanded {
    width: 100%;
}

.spf-nowrap {
    white-space: nowrap;
}

.spf-text-highlight {
    padding: 2px 4px;
    font-size: 90%;
    color: #c7254e;
    background-color: #f9f2f4;
    -moz-border-radius: 2px;
    -webkit-border-radius: 2px;
    border-radius: 2px;
}

.spf-text-highlight-gray {
    padding: 2px 4px;
    font-size: 90%;
    background-color: #f0f0f0;
    -moz-border-radius: 2px;
    -webkit-border-radius: 2px;
    border-radius: 2px;
}

.spf-hidden {
    display: none;
}

.spf-hide {
    display: none !important;
}

.spf-show {
    display: block !important;
}

.spf-opacity {
    opacity: 0.5;
}

.spf-warning-primary {
    color: #fff !important;
    border-color: #d02c21 #ba281e #ba281e !important;
    background: #e14d43 !important;
    -moz-box-shadow: 0 1px 0 #ba281e !important;
    -webkit-box-shadow: 0 1px 0 #ba281e !important;
    box-shadow: 0 1px 0 #ba281e !important;
    text-shadow: 0 -1px 1px #ba281e, 1px 0 1px #ba281e, 0 1px 1px #ba281e, -1px 0 1px !important;
    text-shadow: 0 -1px 1px #ba281e, 1px 0 1px #ba281e, 0 1px 1px #ba281e, -1px 0 1px #ba281e !important;
}

.spf-warning-primary:hover,
.spf-warning-primary:focus {
    border-color: #ba281e !important;
    background: #e35950 !important;
    -moz-box-shadow: 0 1px 0 #ba281e !important;
    -webkit-box-shadow: 0 1px 0 #ba281e !important;
    box-shadow: 0 1px 0 #ba281e !important;
}

.spf-warning-primary:active {
    border-color: #ba281e !important;
    background: #d02c21 !important;
    -moz-box-shadow: inset 0 2px 0 #ba281e !important;
    -webkit-box-shadow: inset 0 2px 0 #ba281e !important;
    box-shadow: inset 0 2px 0 #ba281e !important;
}

.spf-form-result {
    display: none;
    padding: 12px;
    margin: 0 0 15px 0;
    background-color: #fff;
    border-left: 4px solid #555;
    -moz-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.1);
    -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.1);
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.1);
}

.spf-form-show {
    display: block;
}

.spf-form-error {
    border-left-color: #dc3232;
}

.spf-form-success {
    border-left-color: #46b450;
}

.spf-form-warning {
    border-left-color: #ffb900;
}

.spf-form-info {
    border-left-color: #00a0d2;
}

.spf-label-error {
    position: relative;
    top: -2px;
    display: inline-block;
    font-size: 10px;
    line-height: 10px;
    height: 10px;
    width: 10px;
    padding: 1px;
    font-style: normal;
    text-align: center;
    color: #fff;
    vertical-align: middle;
    background-color: #e10000;
    -moz-border-radius: 2px;
    -webkit-border-radius: 2px;
    border-radius: 2px;
}

.spf-no-option {
    padding: 30px;
}

/**
 * 10. Welcome Page
 */

.spf-welcome-wrap {
    position: relative;
    margin: 25px 40px 0 20px;
    font-size: 15px;
    max-width: 1200px;
}

.spf-welcome-wrap p {
    font-size: 14px;
    line-height: 1.5;
}

.spf-welcome-wrap h1 {
    margin: 0.2em 200px 0 0;
    padding: 0;
    color: #32373c;
    line-height: 1.2em;
    font-size: 2.8em;
    font-weight: 400;
}

.spf-welcome-wrap .spf-logo {
    position: absolute;
    overflow: hidden;
    top: 0;
    right: 0;
    height: 160px;
    width: 140px;
    background-image: linear-gradient(45deg, #2d67cb, #ad19f3);
    box-shadow: 0 1px 4px rgba(0, 0, 0, 0.25), inset 0 0 0 4px rgba(0, 0, 0, 0.25);
}

.spf-welcome-wrap .spf-logo .spf--effects i {
    position: absolute;
    width: 200px;
    height: 100px;
    background-color: rgba(0, 0, 0, 0.15);
    transform: rotate(-45deg);
}

.spf-welcome-wrap .spf-logo .spf--effects i:nth-child(1) {
    bottom: -20px;
    right: -70px;
}

.spf-welcome-wrap .spf-logo .spf--effects i:nth-child(2) {
    bottom: -35px;
    right: -80px;
}

.spf-welcome-wrap .spf-logo .spf--effects i:nth-child(3) {
    bottom: -50px;
    right: -90px;
}

.spf-welcome-wrap .spf-logo .spf--effects i:nth-child(4) {
    bottom: -65px;
    right: -100px;
}

.spf-welcome-wrap .spf-logo .spf--wp-logos {
    position: relative;
    padding-top: 25px;
    text-align: center;
}

.spf-welcome-wrap .spf-logo .spf--wp-logo {
    position: absolute;
    left: 20px;
    width: 20px;
    height: 20px;
    background-repeat: no-repeat;
    background-position: center center;
    background-image: url(../images/wp-logo.svg);
}

.spf-welcome-wrap .spf-logo .spf--wp-plugin-logo {
    display: inline-block;
    width: 50px;
    height: 50px;
    border: 3px solid #fff;
    background-size: 40px;
    background-repeat: no-repeat;
    background-position: center center;
    background-image: url(../images/wp-plugin-logo.svg);
    border-radius: 100%;
    vertical-align: middle;
}

.spf-welcome-wrap .spf-logo .spf--text {
    position: absolute;
    left: 0;
    right: 0;
    top: 90px;
    color: #fff;
    font-size: 13px;
    line-height: 1.2em;
    font-weight: 600;
    text-align: center;
    text-transform: uppercase;
    text-shadow: 1px 1px 0 rgba(0, 0, 0, 0.25);
}

.spf-welcome-wrap .spf-logo .spf--version {
    top: auto;
    left: auto;
    right: 8px;
    bottom: 4px;
    font-size: 11px;
    text-transform: lowercase;
}

.spf-welcome-wrap .spf-about-text {
    font-weight: 400;
    line-height: 1.6em;
    font-size: 19px;
    margin: 1em 200px 1em 0;
    color: #555d66;
}

.spf-welcome-wrap .spf-demo-button {
    margin: 1em 200px 2em 0;
}

.spf-welcome-wrap .nav-tab-wrapper {
    margin-bottom: 20px;
}

.spf-welcome-wrap ul {
    list-style-type: disc;
    padding-left: 15px;
}

.spf-welcome-wrap .spf--col {
    float: left;
    padding-right: 20px;
    box-sizing: border-box;
}

.spf-welcome-wrap .spf--col-2 {
    width: 50%;
}

.spf-welcome-wrap .spf--col-3 {
    width: 33.333%;
}

.spf-welcome-wrap .spf--col-4 {
    width: 25%;
}

.spf-welcome-wrap .spf--col-5 {
    width: 20%;
}

.spf-welcome-wrap .spf--col-last {
    padding-right: 0;
}

.spf-welcome-wrap .spf--col-upgrade {
    padding-top: 30px;
    text-align: center;
}

.spf--table-compare thead td,
.spf--table-compare tfoot td {
    text-align: center;
}

.spf--table-compare td {
    font-size: 14px;
    text-align: center;
    vertical-align: middle;
    padding: 10px;
}

.spf--table-compare td:first-child {
    text-align: left;
}

.spf--table-compare tfoot td {
    padding: 15px 0;
}

.spf--table-compare .fa {
    font-size: 12px;
    width: 18px;
    height: 18px;
    line-height: 18px;
    padding: 2px;
    text-align: center;
    color: #fff;
    background-color: #46b450;
    border-radius: 100%;
}

.spf--table-compare .fa-check {
    background-color: #46b450;
}

.spf--table-compare .fa-times {
    background-color: #dc3232;
}

.spf-welcome-cols {
    clear: both;
    margin: 20px 0;
    background-color: #fff;
    padding: 30px 0;
    border-radius: 2px;
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.15);
}

.spf-welcome-cols .spf--col {
    width: 20%;
    float: left;
    padding: 0 30px;
    box-sizing: border-box;
    text-align: center;
    border-right: 1px solid #e5e5e5;
}

.spf-welcome-cols .spf--left,
.spf-welcome-cols .spf--block {
    float: left;
    width: 20%;
    padding: 0 30px;
    text-align: center;
    box-sizing: border-box;
}

.spf-welcome-cols .spf--block {
    width: 80%;
}

.spf-welcome-cols .spf--last {
    border-right: none;
}

.spf-welcome-cols .spf--space {
    height: 20px;
}

.spf-welcome-cols .spf--icon {
    display: inline-block;
    font-size: 25px;
    width: 50px;
    height: 50px;
    line-height: 50px;
    text-align: center;
    margin-bottom: 10px;
    color: #fff;
    background-color: #555;
    border-radius: 50px;
}

.spf-welcome-cols .spf--active {
    background-color: #5cb85c;
}

.spf-welcome-cols .spf--deactive {
    background-color: #e14d43;
}

.spf-welcome-cols .spf--title {
    font-weight: bold;
    display: block;
}

.spf-welcome-cols p:last-child {
    margin-bottom: 0;
}

.spf-code-block {
    margin: 20px 0;
    padding: 5px 20px;
    background-color: #fff;
    border-radius: 2px;
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.15);
}

.spf-code-block pre {
    font-size: 13px;
    color: #0073aa;
}

.spf-code-block pre span {
    color: #999;
}

.spf--table-fields td {
    font-size: 14px;
}

.spf--upgrade a {
    color: #5cb85c;
    font-weight: bold;
}

.spf--upgrade a:focus,
.spf--upgrade a:hover {
    color: #4aa14a;
    outline: none;
    box-shadow: none;
}

/**
 * 11. Responsive
 */

@media only screen and (max-width: 1200px) {
    .spf-metabox .spf-field .spf-title {
        float: none;
        width: 100%;
        margin-bottom: 10px;
    }

    .spf-metabox .spf-field .spf-fieldset {
        margin-left: 0;
    }
}

@media only screen and (max-width: 782px) {
    .spf-header-inner {
        text-align: center;
    }

    .spf-header-inner h1 {
        width: 100%;
        margin-bottom: 10px;
    }

    .spf-search,
    .spf-header-right,
    .spf-header-left {
        width: 100%;
    }

    .spf-search {
        text-align: center;
        margin-bottom: 15px;
    }

    .spf-footer {
        text-align: center;
    }

    .spf-buttons {
        float: none;
    }

    .spf-copyright {
        float: none;
        margin-top: 10px;
    }

    .sp-wpcp-options .spf-nav,
    .spf-nav,
    .spf-expand-all,
    .spf-reset-section,
    .spf-nav-background {
        display: none !important;
    }

    .sp-wpcp-options .spf-content,
    .spf-content {
        margin-left: 0;
    }

    .spf-section-title,
    .sp-wpcp-options .spf-section,
    .spf-section {
        display: block !important;
    }

    .spf-field .spf-title {
        float: none;
        width: 100%;
        margin-bottom: 10px;
    }

    .spf-field .spf-fieldset {
        margin-left: 0;
    }

    .spf-field-radio ul li {
        margin-top: 4px;
    }

    .spf-modal-inner {
        width: 350px;
        height: 380px;
    }

    .spf-modal-content {
        height: 282px;
    }

    .spf-icon-dialog .spf-modal-inner {
        width: 305px;
        height: 380px;
    }

    .spf-icon-dialog .spf-modal-content {
        height: 267px;
    }

    .spf-modal-icon .spf-modal-inner {
        width: 330px;
        height: 385px;
    }

    .spf-modal-icon .spf-modal-content {
        height: 252px;
    }

    .spf-profile>.spf-field>.spf-title {
        float: none;
        width: 100%;
        margin-bottom: 10px;
    }

    .spf-profile>.spf-field>.spf-fieldset {
        margin-left: 0;
    }
}

/**
 * Chosen JS Styles
 */

.chosen-container {
    position: relative;
    display: inline-block;
    vertical-align: middle;
    font-size: 13px;
    user-select: none;
}

.chosen-container * {
    box-sizing: border-box;
}

.chosen-container .chosen-drop {
    position: absolute;
    top: 100%;
    z-index: 1010;
    max-width: 390px;
    /* SP Style */
    width: 100%;
    border: 1px solid #aaa;
    border-top: 0;
    background: #fff;
    box-shadow: 0 4px 5px rgba(0, 0, 0, 0.15);
    clip: rect(0, 0, 0, 0);
    clip-path: inset(100% 100%);
}

.chosen-container.chosen-with-drop .chosen-drop {
    clip: auto;
    clip-path: none;
}

.chosen-container a {
    cursor: pointer;
}

.chosen-container .search-choice .group-name,
.chosen-container .chosen-single .group-name {
    margin-right: 4px;
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
    font-weight: normal;
    color: #999999;
}

.chosen-container .search-choice .group-name:after,
.chosen-container .chosen-single .group-name:after {
    content: ":";
    padding-left: 2px;
    vertical-align: top;
}

.chosen-container-single .chosen-single {
    position: relative;
    display: block;
    overflow: hidden;
    padding: 0 0 0 8px;
    height: 25px;
    border: 1px solid #aaa;
    border-radius: 5px;
    background-color: #fff;
    background: linear-gradient(#ffffff 20%, #f6f6f6 50%, #eeeeee 52%, #f4f4f4 100%);
    background-clip: padding-box;
    box-shadow: 0 0 3px #fff inset, 0 1px 1px rgba(0, 0, 0, 0.1);
    color: #444;
    text-decoration: none;
    white-space: nowrap;
    line-height: 24px;
}

.chosen-container-single .chosen-default {
    color: #999;
}

.chosen-container-single .chosen-single span {
    display: block;
    overflow: hidden;
    margin-right: 26px;
    text-overflow: ellipsis;
    white-space: nowrap;
}

.chosen-container-single .chosen-single-with-deselect span {
    margin-right: 38px;
}

.chosen-container-single .chosen-single abbr {
    position: absolute;
    top: 6px;
    right: 26px;
    display: block;
    width: 12px;
    height: 12px;
    font-size: 1px;
}

.chosen-container-single .chosen-single div {
    position: absolute;
    top: 0;
    right: 0;
    display: block;
    width: 18px;
    height: 100%;
}

.chosen-container-single .chosen-single div b {
    display: block;
    width: 100%;
    height: 100%;
}

.chosen-container-single .chosen-search {
    position: relative;
    z-index: 1010;
    margin: 0;
    padding: 3px 4px;
    white-space: nowrap;
}

.chosen-container-single .chosen-search input[type="text"] {
    margin: 1px 0;
    padding: 4px 20px 4px 5px;
    width: 100%;
    height: auto;
    outline: 0;
    border: 1px solid #aaa;
    font-size: 1em;
    font-family: sans-serif;
    line-height: normal;
    border-radius: 0;
}

.chosen-container-single .chosen-drop {
    margin-top: -1px;
    border-radius: 0 0 4px 4px;
    background-clip: padding-box;
}

.chosen-container-single.chosen-container-single-nosearch .chosen-search {
    position: absolute;
    clip: rect(0, 0, 0, 0);
    clip-path: inset(100% 100%);
}

.chosen-container .chosen-results {
    color: #444;
    position: relative;
    overflow-x: hidden;
    overflow-y: auto;
    margin: 0 4px 4px 0;
    padding: 0 0 0 4px;
    max-height: 240px;
    -webkit-overflow-scrolling: touch;
}

.chosen-container .chosen-results li {
    display: none;
    margin: 0;
    padding: 5px 6px;
    list-style: none;
    line-height: 15px;
    word-wrap: break-word;
    -webkit-touch-callout: none;
}

.chosen-container .chosen-results li.active-result {
    display: list-item;
    cursor: pointer;
    max-width: 390px;
    /* SP Style */
}

.chosen-container .chosen-results li.disabled-result {
    display: list-item;
    color: #ccc;
    cursor: default;
}

.chosen-container .chosen-results li.highlighted {
    background-color: #3875d7;
    background-image: linear-gradient(#3875d7 20%, #2a62bc 90%);
    color: #fff;
}

.chosen-container .chosen-results li.no-results {
    color: #777;
    display: list-item;
    background: #f4f4f4;
}

.chosen-container .chosen-results li.group-result {
    display: list-item;
    font-weight: bold;
    cursor: default;
}

.chosen-container .chosen-results li.group-option {
    padding-left: 15px;
}

.chosen-container .chosen-results li em {
    font-style: normal;
    text-decoration: underline;
}

.chosen-container-multi .chosen-choices {
    position: relative;
    overflow: hidden;
    margin: 0;
    padding: 0 5px;
    max-width: 390px;
    /* SP Style */
    height: auto;
    border: 1px solid #aaa;
    background-color: #fff;
    background-image: linear-gradient(#eeeeee 1%, #ffffff 15%);
    cursor: text;
}

.chosen-container-multi .chosen-choices li {
    float: left;
    list-style: none;
}

.chosen-container-multi .chosen-choices li.search-field {
    margin: 0;
    padding: 0;
    white-space: nowrap;
}

.chosen-container-multi .chosen-choices li.search-field input[type="text"] {
    margin: 1px 0;
    padding: 0;
    height: 25px;
    outline: 0;
    border: 0 !important;
    background: transparent !important;
    box-shadow: none;
    color: #999;
    font-size: 100%;
    font-family: sans-serif;
    line-height: normal;
    border-radius: 0;
    width: 25px;
}

.chosen-container-multi .chosen-choices li.search-choice {
    position: relative;
    margin: 3px 5px 3px 0;
    padding: 3px 20px 3px 5px;
    border: 1px solid #aaa;
    max-width: 100%;
    border-radius: 3px;
    background-color: #eeeeee;
    background-image: linear-gradient(#f4f4f4 20%, #f0f0f0 50%, #e8e8e8 52%, #eeeeee 100%);
    background-size: 100% 19px;
    background-repeat: repeat-x;
    background-clip: padding-box;
    box-shadow: 0 0 2px #fff inset, 0 1px 0 rgba(0, 0, 0, 0.05);
    color: #333;
    line-height: 13px;
    cursor: default;
}

.chosen-container-multi .chosen-choices li.search-choice span {
    word-wrap: break-word;
}

.chosen-container-multi .chosen-choices li.search-choice .search-choice-close {
    position: absolute;
    top: 4px;
    right: 3px;
    display: block;
    width: 12px;
    height: 12px;
    font-size: 1px;
}

.chosen-container-multi .chosen-choices li.search-choice-disabled {
    padding-right: 5px;
    border: 1px solid #ccc;
    background-color: #e4e4e4;
    background-image: linear-gradient(#f4f4f4 20%, #f0f0f0 50%, #e8e8e8 52%, #eeeeee 100%);
    color: #666;
}

.chosen-container-multi .chosen-choices li.search-choice-focus {
    background: #d4d4d4;
}

.chosen-container-multi .chosen-results {
    margin: 0;
    padding: 0;
}

.chosen-container-multi .chosen-drop .result-selected {
    display: none;
    /* SP Style */
    color: #ccc;
    cursor: default;
}

.chosen-container-active .chosen-single {
    border: 1px solid #5897fb;
    box-shadow: 0 0 5px rgba(0, 0, 0, 0.3);
}

.chosen-container-active.chosen-with-drop .chosen-single {
    border: 1px solid #aaa;
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0;
    background-image: linear-gradient(#eeeeee 20%, #ffffff 80%);
    box-shadow: 0 1px 0 #fff inset;
}

.chosen-container-active.chosen-with-drop .chosen-single div {
    border-left: none;
    background: transparent;
}

.chosen-container-active .chosen-choices {
    border: 1px solid #5897fb;
    box-shadow: 0 0 5px rgba(0, 0, 0, 0.3);
}

.chosen-container-active .chosen-choices li.search-field input[type="text"] {
    color: #222 !important;
}

.chosen-disabled {
    opacity: 0.5 !important;
    cursor: default;
}

.chosen-disabled .chosen-single {
    cursor: default;
}

.chosen-disabled .chosen-choices .search-choice .search-choice-close {
    cursor: default;
}

.chosen-rtl {
    text-align: right;
}

.chosen-rtl .chosen-single {
    overflow: visible;
    padding: 0 8px 0 0;
}

.chosen-rtl .chosen-single span {
    margin-right: 0;
    margin-left: 26px;
    direction: rtl;
}

.chosen-rtl .chosen-single-with-deselect span {
    margin-left: 38px;
}

.chosen-rtl .chosen-single div {
    right: auto;
    left: 3px;
}

.chosen-rtl .chosen-single abbr {
    right: auto;
    left: 26px;
}

.chosen-rtl .chosen-choices li {
    float: right;
}

.chosen-rtl .chosen-choices li.search-field input[type="text"] {
    direction: rtl;
}

.chosen-rtl .chosen-choices li.search-choice {
    margin: 3px 5px 3px 0;
    padding: 3px 5px 3px 19px;
}

.chosen-rtl .chosen-choices li.search-choice .search-choice-close {
    right: auto;
    left: 4px;
}

.chosen-rtl.chosen-container-single .chosen-results {
    margin: 0 0 4px 4px;
    padding: 0 4px 0 0;
}

.chosen-rtl .chosen-results li.group-option {
    padding-right: 15px;
    padding-left: 0;
}

.chosen-rtl.chosen-container-active.chosen-with-drop .chosen-single div {
    border-right: none;
}

.chosen-rtl .chosen-search input[type="text"] {
    padding: 4px 5px 4px 20px;
    direction: rtl;
}

/**
 *
 *Custom Style for the WPCP
 *
 **/

#sp_wpcp_shortcode_options {
    border-top-color: #f1f1f1;
}

#sp_wpcp_shortcode_options .spf-nav ul li {
    margin-bottom: -1px;
}

#sp_wpcp_shortcode_options .spf-nav.spf-nav-metabox {
    border-right-color: #f1f1f1;
    border-right-color: #f1f1f1;
    background: #f1f1f1;
    margin-right: -2px;
}

#sp_wpcp_shortcode_options .spf-content {
    border-top: 1px solid #e5e5e5;
    box-shadow: 0 -1px 1px rgba(0, 0, 0, .04);
}

#spf-section-sp_wpcp_upload_options_1 .spf-field-carousel_type .spf-title,
#spf-section-sp_wpcp_upload_options_1 .spf-field-gallery .spf-title,
.wpcp_carousel_content_wrapper .spf-title,
.wpcp-video-description .spf-title,
.wpcp-video-field-wrapper>.spf-title {
    width: 100%;
}

#spf-section-sp_wpcp_upload_options_1 .spf-field-carousel_type .spf-fieldset,
#spf-section-sp_wpcp_upload_options_1 .spf-field-gallery .spf-fieldset,
.wpcp_carousel_content_wrapper .spf-fieldset,
.wpcp-video-description .spf-fieldset,
.wpcp-video-field-wrapper>.spf-fieldset {
    margin-top: 30px;
    margin-left: 0;
}

#sp_wpcp_display_shortcode .hndle,
#sp_wpcp_display_shortcode .handlediv,
#sp_wpcp_display_shortcode .postbox-header,
#sp_wpcp_shortcode_options .hndle,
#sp_wpcp_shortcode_options .handlediv,
#sp_wpcp_shortcode_options .postbox-header,
#sp_wpcp_upload_options .handlediv,
#sp_wpcp_upload_options .postbox-header,
#sp_wpcp_upload_options .hndle {
    display: none;
}

#spf-section-sp_wpcp_upload_options_1 .wpcp-admin-header {
    background-color: #157592;
    background: linear-gradient(-45deg, #22afba, #157592);
    padding: 20px 26px;
    overflow: hidden;
    height: 33px;
}

#spf-section-sp_wpcp_upload_options_1 .wpcp-admin-header .support {
    margin-left: 16px;
    float: right;
}

#spf-section-sp_wpcp_upload_options_1 .wpcp-admin-header .support a {
    color: #ffffff;
    text-decoration: none;
    line-height: 35px;
    font-size: 15px;
    font-weight: 500;
}

/**
 Free version CSS.
*/
.spf-field-carousel_type .spf--image:nth-child(4),
.spf-field-carousel_type .spf--image:nth-child(5) {
    pointer-events: none;
}
.spf-field-carousel_type .spf--image {
    position: relative;
}
.spf-field-carousel_type .spf--image label strong {
    position: absolute;
    top: 3px;
    right: 3px;
    background: #cbd6df;
    padding: 0px 5px;
    font-size: 10px;
}
#sp_wpcp_shortcode_options .hidden{
    display: none;
}

/*
 * Shortcode footer.
 */
.spf-field-shortcode.wpcp-admin-footer .wpcp-shortcode-selectable {
    background-color: rgba(82, 179, 217, 0.11);
    padding: 10px 15px 10px 28px;
    display: inline-block;
    -webkit-touch-callout: all;
    -webkit-user-select: all;
    -khtml-user-select: all;
    -moz-user-select: all;
    -ms-user-select: all;
    user-select: all;
    border: 1px solid rgba(82, 179, 217, 0.2);
    border-radius: 2px;
    cursor: pointer;
    position: relative;
}
.spf-field-shortcode.wpcp-admin-footer .wpcp-shortcode-selectable::after {
    content: url(../images/copy.svg);
    width: 16px;
    left: 10px;
    top: 50%;
    position: absolute;
    margin-top: -7px;
}
.spf-field-shortcode.wpcp-admin-footer .sptp-copy-btn {
    width: 16px;
    margin-left: 13px;
    position: absolute;
    top: 50%;
    margin-top: -8px;
}
#spf-section-sp_wpcp_display_shortcode_1 .spf-field {
    display: flex;
    padding: 0;
    flex-wrap: wrap;
}
.spf-field-shortcode.wpcp-admin-footer .wpcp-scode-wrap:first-of-type {
    border-right: 1px solid #ddd;
}
.spf-field-shortcode.wpcp-admin-footer .wpcp-scode-wrap {
    padding-top: 22px;
    padding-bottom: 22px;
    text-align: center;
    width: 49%;
}
.spf-field-shortcode.wpcp-admin-footer .wpcp-sc-title {
    font-weight: 500;
    font-size: 14px !important;
    padding-top: 0 !important;
    color: #4c5158;
    margin-right: 5px;
}

@media only screen and (max-width: 990px) {
    .spf-field-shortcode.wpcp-admin-footer .wpcp-scode-wrap:first-of-type {
        border-right: none;
        border-bottom: 1px solid #ddd;
    }

    .spf-field-shortcode.wpcp-admin-footer .wpcp-scode-wrap {
        width: 100%;
    }
}

/* Pro only field css */
.spf-field-image_select .spf--image.spf-pro-only,
.spf-field-button_set .spf--button.spf-pro-only {
    color: rgba(85, 85, 85, 0.6) !important;
    pointer-events: none;
}
.spf-field-button_set .spf--button.spf-pro-only {
    background-color: rgba(247, 247, 247, 0.4) !important;
}

.spf-field.spf-field-switcher.only_pro_switcher .spf--ball::after{
    content: "PRO";
    position: relative;
    text-align: center;
    width: 24px;
    float: right;
    font-weight: 600;
    font-size: 8px;
    color: #a5a5a5;
    opacity: 1;
    line-height: 18px;
}
.spf-field-button_set .spf--button.spf-pro-only:after,
.spf-field-image_select .spf--image.spf-pro-only:after {
    position: absolute;
    top: 0;
    right: 0;
    color: #a5a5a5;
    background-color: #e0e0e0;
    font-weight: 500;
    padding: 0 4px;
    content: "PRO";
    text-align: center;
    font-size: 8px;
    line-height: 11px;
    opacity: 1;
}
.spf-field.spf-field-switcher.only_pro_switcher .spf--switcher{
    background: #cbcfd0;
    pointer-events: none;
}
#spf-section-sp_wpcp_upload_options_1 .wpcp-admin-header img {
    max-width: 200px;
}
/* hide setting page wraper title */
.sp_wp_carousel_page_wpcp_settings .wrap h1 {
    display: none;
}
.spf-notice {
    color: #999;
    font-style: italic;
    font-size: 13px;
    padding: 12px 12px 12px 0!important;
    border: none!important;
}
.spf-field-notice{
    background-color: transparent!important;
}