/* Premium page  */
.sp_wp_carousel_page_wpcf_upgrade #wpbody-content {
  padding-bottom: 0;
  background-color: #fff;
}

.sp_wp_carousel_page_wpcf_upgrade #wpcontent {
  padding-left: 0;
}

/*----------------------------------------*/
/*  Grid Layout
/*----------------------------------------*/
.sp-wp-carousel-premium-page .sp-wpc__container {
  width: 90%;
  padding-right: 15px;
  padding-left: 15px;
  margin-right: auto;
  margin-left: auto;
}

@media (min-width: 576px) {
  .sp-wp-carousel-premium-page .sp-wpc__container {
    max-width: 540px;
  }
}

@media (min-width: 768px) {
  .sp-wp-carousel-premium-page .sp-wpc__container {
    max-width: 720px;
  }
}

@media (min-width: 991px) {
  .sp-wp-carousel-premium-page .sp-wpc__container {
    max-width: 960px;
  }
}

@media (min-width: 1200px) {
  .sp-wp-carousel-premium-page .sp-wpc__container {
    max-width: 1170px;
  }
}

.sp-wp-carousel-premium-page .row {
  display: block;
  flex-wrap: wrap;
  margin-right: -15px;
  margin-left: -15px;
  justify-content: center;
}

@media (min-width: 1200px) {
  .sp-wp-carousel-premium-page .row {
    display: flex;
  }
}

@media (min-width: 768px) {
  .sp-wp-carousel-premium-page .sp-wpc__col-md-12 {
    flex: 0 0 100%;
    max-width: 100%;
  }
}

@media (min-width: 1200px) {
  .sp-wp-carousel-premium-page .sp-wpc__col-xl-6 {
    flex: 0 0 50%;
    max-width: 50%;
  }
}

/* font family */
/* base */
h2,
h3 {
  margin: inherit;
  line-height: initial;
}

/* utility css */
/* margin top css */
.sp-wp-carousel-premium-page .sp-wpc__mt-10 {
  margin-top: 10px;
}

.sp-wp-carousel-premium-page .sp-wpc__mt-15 {
  margin-top: 15px;
}

.sp-wp-carousel-premium-page .sp-wpc__mt-20 {
  margin-top: 20px;
}

.sp-wp-carousel-premium-page .sp-wpc__mt-25 {
  margin-top: 20px;
}

.sp-wp-carousel-premium-page .sp-wpc__mt-40 {
  margin-top: 15px;
}

.sp-wp-carousel-premium-page .sp-wpc__buy .sp-wpc__mt-40 {
  margin-top: 20px;
}

/* margin left css */
.sp-wp-carousel-premium-page .ml-16 {
  margin-left: 16px;
}

.sp-wp-carousel-premium-page .ml-30 {
  margin-left: 0px;
}

@media screen and (min-width: 768px) {
  .sp-wp-carousel-premium-page .ml-30 {
    margin-left: 30px;
  }
}

.sp-wp-carousel-premium-page .mr-30 {
  margin-right: 0px;
}

@media screen and (min-width: 768px) {
  .sp-wp-carousel-premium-page .mr-30 {
    margin-right: 30px;
  }
}

/* font size */
.sp-wp-carousel-premium-page .sp-wpc__font-12 {
  font-size: 12px;
}

.sp-wp-carousel-premium-page .sp-wpc__font-14 {
  font-size: 14px;
}

.sp-wp-carousel-premium-page .sp-wpc__font-15 {
  font-size: 15px;
}

.sp-wp-carousel-premium-page .sp-wpc__font-16 {
  font-size: 16px;
}

.sp-wp-carousel-premium-page .sp-wpc__font-18 {
  font-size: 18px;
}

.sp-wp-carousel-premium-page .sp-wpc__font-24 {
  font-size: 24px;
}

.sp-wp-carousel-premium-page .sp-wpc__font-28 {
  font-size: 28px;
}

.sp-wp-carousel-premium-page .sp-wpc__font-30 {
  font-size: 30px;
}

/* line-height */
.sp-wp-carousel-premium-page .sp-wpc__font-weight-400 {
  font-weight: 400;
}

.sp-wp-carousel-premium-page .sp-wpc__font-weight-500 {
  color: #124E53;
  font-weight: 600;
}

.sp-wp-carousel-premium-page .sp-wpc__font-weight-700 {
  font-weight: 700;
}

/* text-align */
.sp-wp-carousel-premium-page .text-center {
  text-align: center;
}

/* color */
.sp-wp-carousel-premium-page .text-color {
  color: #444444;
}

.sp-wp-carousel-premium-page .text-color-2 {
  color: #165055;
}

/* line-height */
.sp-wp-carousel-premium-page .sp-wpc__line-height-20 {
  line-height: 20px;
}

.sp-wp-carousel-premium-page .sp-wpc__line-height-22 {
  line-height: 22px;
  color:#124E53;
}

.sp-wp-carousel-premium-page .sp-wpc__line-height-24 {
  line-height: 24px;
}

/* css blog component */
.sp-wp-carousel-premium-page .sp-wpc__btn {
  text-decoration: none;
  font-size: 14px;
  display: inline-block;
  padding: 13px 20px;
  border-radius: 3px;
  text-transform: uppercase;
}

.sp-wp-carousel-premium-page .sp-wpc__btn-sky {
  background-color: #1BA2AC;
  color: #fff;
  font-weight: 500;
  text-transform: uppercase;
  padding: 15px 20px;
}

.sp-wp-carousel-premium-page .sp-wpc__btn-sky:hover {
  background-color: #198E94;
}

.sp-wp-carousel-premium-page .sp-wpc__btn-border {
  color: #124E53;
  background-color: rgb(223, 247, 247);
  font-weight: 500;
  border: 2px solid #124E53;
}

.sp-wp-carousel-premium-page .sp-wpc__btn-border:hover {
  background-color: #1BA2AC;
  border: 2px solid #1BA2AC;
  color: #fff;
}

.sp-wp-carousel-premium-page .sp-wpc__btn-border::after {
  content: "\f105 ";
  font-family: FontAwesome;
  margin-left: 5px;
  font-size: 16px;
}

.sp-wp-carousel-premium-page .sp-wpc__btn-buy {
  font-size: 16px;
  background-color: #1BA2AC;
  color: #fff;
  font-weight: 600;
  padding: 18px 35px;
  text-transform: inherit;
}

.sp-wp-carousel-premium-page .sp-wpc__btn-buy:hover {
  background-color: #198E94;
  color: #fff;
}

/* sp-wpc__banner Section css */
.sp-wp-carousel-premium-page .sp-wpc__banner {
  background-color: rgb(223, 247, 247);
  overflow: hidden;
  padding-bottom: 150px;
}

@media screen and (min-width: 1200px) {
  .sp-wp-carousel-premium-page .sp-wpc__banner {
    height: 600px;
    padding-bottom: 0;
  }
}

.sp-wp-carousel-premium-page .sp-wpc__banner .sp-wpc__banner-content p {
  font-size: 15px;
}

.sp-wp-carousel-premium-page .sp-wpc__banner .sp-wpc__banner-content {
  padding-top: 120px;
  padding-right: 15px;
  padding-left: 15px;
}

@media screen and (min-width: 576px) {
  .sp-wp-carousel-premium-page .sp-wpc__banner .sp-wpc__banner-content {
    padding-right: 0px;
    padding-left: 0px;
  }
}

.sp-wp-carousel-premium-page .sp-wpc__banner-button {
  display: flex;
  flex-direction: column;
  align-items: center;
}

@media screen and (min-width: 576px) {
  .sp-wp-carousel-premium-page .sp-wpc__banner-button {
    display: inline-block;
  }
}

.sp-wp-carousel-premium-page .sp-wpc__banner .sp-wpc__banner-img {
  padding-top: 50px;
  width: 80%;
  margin: 0 auto;
  position: relative;
}

@media screen and (min-width: 992px) {
  .sp-wp-carousel-premium-page .sp-wpc__banner .sp-wpc__banner-img {
    padding-top: 100px;
  }
}

.sp-wp-carousel-premium-page .sp-wp-carousel-premium-page .sp-wpc__banner .sp-wpc__banner-content p {
  font-family: "Roboto", sans-serif;
}

.sp-wp-carousel-premium-page .sp-wpc__banner .sp-wpc__banner-content h4 strong {
  font-style: italic;
}

/* count section css */
.sp-wp-carousel-premium-page .sp-wpc__count-area {
  width: 100%;
  margin: 0 auto;
  background-color: #fff;
  padding: 40px 80px;
  margin-top: -50px;
  border-radius: 5px;
  display: flex;
  box-sizing: border-box;
  justify-content: space-between;
  box-shadow: 0 1px 10px 0 #eaeaea;
}

@media screen and (max-width: 576px) {
  .sp-wp-carousel-premium-page .sp-wpc__count-area {
    display: block;
  }

  .sp-wp-carousel-premium-page .sp-wpc__count-area .count-item {
    padding-bottom: 30px;
  }
}

@media screen and (min-width: 576px) {
  .sp-wp-carousel-premium-page .sp-wpc__count-area {
    width: 70%;
  }
}

/* .sp-wp-carousel-premium-page  .sp-wpc__count-area .count-item {
    text-align: center;
  } */

.sp-wp-carousel-premium-page .sp-wpc__count-area .count-item span {
  color: #67757a;
  margin-top: 10px;
  display: inline-block;
  text-transform: uppercase;
  font-size: 12px;
}

/* Video Section CSS */
.sp-wp-carousel-premium-page .sp-wpc__video {
  margin-top: 94px;
}

.sp-wp-carousel-premium-page .sp-wpc__video .video-area {
  position: relative;
  width: 100%;
  margin: 0 auto;
  margin-top: 60px;
}

@media screen and (min-width: 576px) {
  .sp-wp-carousel-premium-page .sp-wpc__video .video-area {
    width: 80%;
  }
}

.sp-wp-carousel-premium-page .sp-wpc__video .video-area::after {
  position: absolute;
  content: "";
  width: 100%;
  background-color: #8ED6DC;
  top: 0;
  left: 0;
  bottom: 5px;
  opacity: 50%;
  border-radius: 10px;
  z-index: 1;
}

.sp-wp-carousel-premium-page .sp-wpc__video .video-area img {
  border-radius: 10px;
}

.sp-wp-carousel-premium-page .sp-wpc__video .video-area .video-button {
  position: absolute;
  z-index: 2;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
}

.sp-wp-carousel-premium-page .sp-wpc__video .video-area .video-button a {
  width: 100px;
  height: 100px;
  font-size: 34px;
  background-color: #fff;
  border-radius: 50%;
  display: flex;
  justify-content: center;
  align-items: center;
  color: #39505b;
  transition: 0.3s;
  text-decoration: none;
}

.sp-wp-carousel-premium-page .sp-wpc__video .video-area .video-button a span {
  transform: translateX(4px);
}

.sp-wp-carousel-premium-page .sp-wpc__video .video-area .video-button a:focus {
  box-shadow: none;
  border: none;
}

.sp-wp-carousel-premium-page .sp-wpc__video .video-area .video-button a:hover {
  background-color: #1DADB9;
  color: #fff;
}

/* Feature Section css */
.sp-wp-carousel-premium-page .sp-wpc__feature {
  background-color: #f1f5f9;
  padding-top: 174px;
  margin-top: -80px;
  padding-bottom: 100px;
}

.sp-wp-carousel-premium-page .sp-wpc__feature .feature-area {
  display: flex;
  flex-wrap: wrap;
}

@media screen and (min-width: 768px) {
  .sp-wp-carousel-premium-page .sp-wpc__feature .feature-area {
    flex-wrap: nowrap;
  }
}

.sp-wp-carousel-premium-page .sp-wpc__feature .feature-area .feature-item p {
  margin-bottom: 0;
}

.sp-wp-carousel-premium-page .sp-wpc__feature .feature-area .feature-item {
  width: 100%;
  padding: 35px 35px 35px 35px;
  background-color: #fff;
  margin-top: 50px;
  border-radius: 5px;
  box-shadow: 0 2px 10px 0 rgb(0 0 0 / 6%);
  display: flex;
  margin-right: 25px;
}

@media screen and (min-width: 768px) {
  .sp-wp-carousel-premium-page .sp-wpc__feature .feature-area .feature-item {
    width: 50%;
  }
}

.sp-wp-carousel-premium-page .sp-wpc__feature .feature-area .feature-item .feature-icon img {
  border: none;
  max-width: 100%;
  padding: 15px;
  display: block;
  box-sizing: border-box;
}

.sp-wp-carousel-premium-page .sp-wpc__feature .feature-area .feature-item .feature-icon {
  width: 50px;
  height: 50px;
  border-radius: 50%;
  background-color: #D5F2F4;
  display: flex;
  justify-content: center;
  align-items: center;
  flex: none;
  margin-right: 20px;

}

.sp_wp_carousel_page_wpcf_upgrade #wpfooter {
  display: none;

}

/* buy section css */
.sp-wp-carousel-premium-page .sp-wpc__buy {
  padding-top: 100px;
  padding-bottom: 100px;
  background-image: -moz-linear-gradient(90deg, rgb(33, 175, 185) 0%, #B7ECEE 0%, rgb(255, 255, 255) 100%);
  background-image: -webkit-linear-gradient(90deg, rgb(33, 175, 185) 0%, #B7ECEE 0%, rgb(255, 255, 255) 100%);
  background-image: -ms-linear-gradient(90deg, rgb(33, 175, 185) 0%, #B7ECEE 0%, rgb(255, 255, 255) 100%);
}


.sp-wp-carousel-premium-page .sp-wpc__banner .sp-wpc__banner-img::before,
.sp-wp-carousel-premium-page .sp-wpc__buy .buy-img::before {
  position: absolute;
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  width: 100%;
  height: 100%;
  content: '';
  z-index: 99;
}

.sp-wp-carousel-premium-page .sp-wpc__buy .buy-img {
  width: 80%;
  position: relative;
  margin: 0 auto;
  padding-bottom: 25px;
}

.sp-wp-carousel-premium-page .sp-wpc__feature .feature-area .feature-item .feature-icon.custom-padding img {
  padding: 10px
}

.sp-wp-carousel-premium-page .sp-wpc__buy .buy-content h2 {
  color: #124E53;
}

.sp-wp-carousel-premium-page .sp-wpc__buy .buy-content span {
  display: block;
  font-size: 11px;
  margin-top: 12px;
  color: #678280;
}

/*----------------------------------------*/
/*  testimonial section css
/*----------------------------------------*/
.sp-wp-carousel-premium-page .testimonial-wrapper {
  background-color: #f1f5f9;
  padding-bottom: 50px;
  padding-top: 10px;
}

.sp-wp-carousel-premium-page .sp-wpc__premium.testimonial .row {
  flex-wrap: nowrap;
}

.sp-wp-carousel-premium-page .sp-wpc__premium.testimonial {
  width: 90%;
  margin: 0 auto;
}

@media screen and (min-width: 992px) {
  .sp-wp-carousel-premium-page .sp-wpc__premium.testimonial {
    width: 80%;
  }
}

@media screen and (min-width: 1200px) {
  .sp-wp-carousel-premium-page .sp-wpc__premium.testimonial {
    width: 960px;
  }
}

.sp-wp-carousel-premium-page .sp-wpc__premium.testimonial .col,
.sp-wp-carousel-premium-page .col-lg-6 {
  padding-right: 20px;
  padding-left: 20px;
}

.sp-wp-carousel-premium-page .sp-wpc__premium.testimonial .testimonial-area {
  margin-top: 30px;
}

.sp-wp-carousel-premium-page .sp-wpc__premium.testimonial .testimonial-area .testimonial-content {
  background-color: #fff;
  border-radius: 5px;
  position: relative;
  box-shadow: 0px 0px 15px 0px rgba(0, 0, 0, 0.05);
}

.sp-wp-carousel-premium-page .sp-wpc__premium.testimonial .testimonial-area .testimonial-content::after {
  position: absolute;
  content: "";
  border-style: solid;
  border-color: transparent;
  border-width: 18px 18px 0;
  border-top-color: #ffff;
  bottom: -16px;
  left: 45px;
}

.sp-wp-carousel-premium-page .sp-wpc__premium.testimonial .testimonial-area .testimonial-content p {
  padding: 25px 40px;
  font-size: 14px;
  font-weight: 400;
  line-height: 24px;
  font-style: italic;
}

.sp-wp-carousel-premium-page .sp-wpc__premium.testimonial .testimonial-area .testimonial-info {
  display: flex;
  margin-top: 25px;
  margin-left: 30px;
}

.sp-wp-carousel-premium-page .sp-wpc__premium.testimonial .testimonial-area .testimonial-info .img img {
  border-radius: 50%;
  height: 60px;
}

.sp-wp-carousel-premium-page .sp-wpc__premium.testimonial .testimonial-area .testimonial-info .info {
  margin-left: 15px;
  align-self: center;
}

.sp-wp-carousel-premium-page .sp-wpc__premium.testimonial .testimonial-area .testimonial-info .info h3 {
  font-size: 15px;
  margin-top: 0;
  margin-bottom: 0;
  font-weight: 500;
  margin-left: 0;
}

.sp-wp-carousel-premium-page .sp-wpc__premium.testimonial .testimonial-area .testimonial-info .info .star {
  display: flex;
  margin-top: 5px;
}

.sp-wp-carousel-premium-page .sp-wpc__premium.testimonial .testimonial-area .testimonial-info .info .star .fa {
  font-size: 15px;
  margin-right: 1px;
  color: #ffb900;

}

.sp-wp-carousel-premium-page .sp-wpc__premium.testimonial .testimonial-area .testimonial-info .info p {
  font-size: 12px;
  color: #808080;
  margin-top: 5px;
  margin-bottom: 0;
}

.sp-wp-carousel-premium-page *:focus {
  box-shadow: none;
  outline: none;
}