/**
 *
 * ---------------------------------------------------------
 * CSF RTL CSS MAP
 * ---------------------------------------------------------
 *
 * 01. Base
 *     01. 01. Header
 *     01. 02. Header Buttons
 *     01. 03. Navigation
 *     01. 04. Content
 *     01. 05. Section
 *     01. 06. Show All Options
 *     01. 07. Search Input
 *     01. 08. Copyright
 *     01. 09. Metabox
 * 02. Fields
 *     02. 01. Field: typography
 *     02. 02. Field: checkbox, radio
 *     02. 03. Field: switcher
 *     02. 04. Field: upload
 *     02. 05. Field: group
 *     02. 06. Field: repeater
 *     02. 07. Field: help
 *     02. 08. Field: icon
 *     02. 09. Field: gallery
 *     02. 10. Field: sorter
 *     02. 11. Field: tabbed
 *     02. 12. Field: media
 *     02. 13. Field: notice
 *     02. 14. Field: border, spacing, dimensions, column, dimensions_advanced
 *     02. 15. Field: background
 *     02. 16. Field: spinner
 *     02. 17. Field: slider
 *     02. 18. Field: button_set
 *     02. 19. Field: link_color
 *     02. 20. Field: color_group
 *     02. 21. Field: palette
 * 03. Taxonomy
 * 04. Modal
 * 05. Customizer
 * 06. Responsive
 * 07. Others
 *
 * ---------------------------------------------------------
 *
 */
 
/**
 * 01. Base
 */
.spf {
    margin-left: 20px;
    margin-right: 0;
}

/**
 * 01. 01. Header
 */
.spf-header h1 {
    float: right;
}

.spf-header fieldset {
    float: left;
}

/**
 * 01. 02. Header Buttons
 */
.spf-buttons {
    float: left;
    direction: ltr;
}

.spf-header-left {
    float: right;
}

.spf-header-right {
    float: left;
}

/**
 * 01. 03. Navigation
 */
.spf-nav {
    float: right;
}

.spf-nav ul {
    clear: right;
}

.spf-nav ul li .spf-section-active:after {
    right: auto;
    left: 0;
    border-left-color: #fff;
    border-right-color: transparent;
}

.spf-nav ul li .spf-arrow:after {
    content: "\f053";
    right: auto;
    left: 10px;
}

.spf-nav ul li.spf-tab-active .spf-arrow:after {
    -moz-transform: rotate(-90deg);
    -ms-transform: rotate(-90deg);
    -webkit-transform: rotate(-90deg);
    transform: rotate(-90deg);
}

.spf-nav ul ul li a {
    padding-right: 25px;
    padding-left: 15px;
}

.spf-nav ul ul:before {
    left: auto;
    right: 15px;
}

.spf-nav .fa {
    margin-left: 5px;
    margin-right: 0;
}

.spf-nav-background {
    left: auto;
    right: 0;
}

/**
 * 01. 04. Content
 */
.spf-content {
    margin-left: 0;
    margin-right: 225px;
}

/**
 * 01. 05. Section
 */
.spf-sections {
    float: right;
}

/**
 * 01. 06. Show all options
 */
.spf-show-all .spf-content {
    margin-right: 0;
    overflow: hidden;
}

.spf-expand-all {
    float: right;
    right: auto;
    left: 40px;
    margin-right: 0;
    margin-left: 4px;
}

/**
 * 01. 07. Search Input
 */
.spf-search {
    float: right;
}

.spf-search input {
    margin: 0 0 0 5px;
}

/**
 * 01. 08. Copyright
 */
.spf-copyright {
    float: right;
}

/**
 * 01. 09. Metabox
 */
.spf-metabox {
    margin: -6px -12px -12px -12px;
}

.spf-metabox .spf-section-title {
    padding: 20px;
}

.spf-metabox .spf-section-title .fa {
    margin-left: 5px;
    margin-right: 0;
}

.spf-section-title .fa {
    margin-left: 5px;
    margin-right: 0;
}

/**
 * 02. Fields
 */
.spf-field .spf-title {
    float: right;
}

.spf-field .spf-fieldset {
    margin-left: 0;
    margin-right: 30%;
}

.spf-pseudo-field {
    padding: 0 0 0 5px !important;
}

/**
 * 02. 01. Field: typography
 */
.spf-field-typography select {
    margin: 0;
    width: 100%;
}

.spf-field-typography .spf--blocks-inputs .spf--blocks {
    flex-direction: row-reverse;
}

/**
 * 02. 02. Field: checkbox, radio
 */
.spf-field-checkbox .spf--inline-list li,
.spf-field-radio .spf--inline-list li {
    margin-right: 0;
    margin-left: 15px;
}

/**
 * 02. 03. Field: switcher
 */
.spf-field-switcherf .spf--switcher,
.spf-field-switcher .spf--switcher {
    float: right;
}

.spf-field-switcherf .spf--label,
.spf-field-switcher .spf--label {
    float: right;
    margin-left: 0;
    margin-right: 5px;
}

/**
 * 02. 04. Field: upload
 */
.spf-field-upload .spf--remove,
.spf-field-upload .spf--buttons {
    margin-left: 0;
    margin-right: 5px;
}

/**
 * 02. 05. Field: group
 */
.spf-field-group .spf-cloneable-title {
    padding: 15px 10px 15px 65px;
}

.spf-field-group .spf-cloneable-helper {
    right: auto;
    left: 10px;
}

/**
 * 02. 06. Field: repeater
 */
.spf-field-repeater .spf-repeater-helper {
    border-left: 0;
    border-right: 1px solid #eee;
}

/**
 * 02. 07. Field: help
 */
.spf-help {
    right: auto;
    left: 5px;
}

/**
 * 02. 08. Field: icon
 */
.spf-field-icon .button {
    margin-right: 0;
    margin-left: 5px;
}

.spf-field-icon .spf-icon-preview i {
    margin-right: 0;
    margin-left: 5px;
}

/**
 * 02. 09. Field: gallery
 */

.spf-field-gallery ul.sp-gallery-images li,
.button:focus,
.spf-field-gallery .button:hover,
.spf-field-gallery .button  {
    margin-right: 0;
    margin-left: 5px;
}

/*
Custom Style
*/
.spf-field-gallery a,
.spf-field-gallery li {
    float: right;
}

/*
 * 02. 11. Field: tabbed
 */
.spf-field-tabbed .spf-tabbed-nav .fa {
    padding-right: 0;
    padding-left: 5px;
}

.spf-field-tabbed .spf-tabbed-nav a {
    margin-right: 0;
    margin-left: 5px;
}

/**
 * 02. 12. Field: media
 */
.spf-field-media .button {
    margin-left: 0;
    margin-right: 7px;
}

.spf-field-media .hidden+.button {
    margin-right: 0;
}

/**
 * 02. 13. Field: notice
 */
.spf-notice {
    border-left: none;
    border-right-style: solid;
    border-right-width: 4px;
}

/**
 * 02. 14. Field: border, spacing, dimensions, column, dimensions_advanced
 */
.spf-field-dimensions_advanced .spf--input,
.spf-field-column .spf--input,
.spf-field-dimensions .spf--input,
.spf-field-spacing .spf--input,
.spf-field-border .spf--input {
    float: right;
    margin-right: 0;
    margin-left: 15px;
}

.spf-field-dimensions_advanced .spf--left,
.spf-field-column .spf--left,
.spf-field-dimensions .spf--left,
.spf-field-spacing .spf--left,
.spf-field-border .spf--left {
    float: right;
}

/**
 * 02. 15. Field: background
 */
.spf-field-background .spf--block {
    float: right;
}

.spf-field-background .spf--select,
.spf-field-background .spf--media {
    padding-right: 0;
}

.spf-field-background .spf--title {
    margin-right: 0;
    margin-left: 5px;
}

/**
 * 02. 16. Field: spinner
 */
.spf-field-spinner .spf--spin {
    float: right;
}

/**
 * 02. 17. Field: slider
 */
.spf-field-slider .ui-slider {
    direction: ltr;
}

.spf-field-slider input[type="text"] {
    margin-left: 0;
    margin-right: 15px;
}

.spf-field-slider em {
    padding-left: 0;
    padding-right: 5px;
}

/**
 * 02. 18. Field: button_set
 */
.spf-field-button_set .spf--button-group {
    float: right;
}

/**
 * 02. 19. Field: link_color
 */
.spf-field-link_color .spf--left {
    float: right;
    margin-right: 0;
    margin-left: 10px;
}

/**
 * 02. 20. Field: color_group
 */
.spf-field-color_group .spf--left {
    float: right;
    margin-right: 0;
    margin-left: 10px;
}

/**
 * 02. 21. Field: palette
 */
.spf-field-palette .spf--palette {
    margin-right: 0;
    margin-left: 10px;
}

/**
 * 03. Taxonomy
 */
.spf-taxonomy-add-fields .spf-fieldset {
    margin-right: 0;
}

.spf-taxonomy-add-fields .spf-field>.spf-fieldset>.spf-help {
    left: -5px;
    right: auto;
}

.spf-taxonomy-edit-fields .spf-fieldset {
    margin-left: 0;
    margin-right: 225px;
}

.spf-taxonomy-edit-fields .spf-field>.spf-fieldset>.spf-help {
    right: auto;
    left: -5px;
}

/**
 * 04. Modal
 */
.spf-modal-content .spf-field {
    padding: 15px 15px 15px 30px;
}

.spf-modal-title {
    padding: 0 16px 0 36px;
}

.spf-modal-close {
    right: auto;
    left: 0;
}

/**
 * 05. Customizer
 */
.control-section .spf-field .spf-fieldset {
    margin-right: 0;
}

/**
 * 06. Responsive
 */
@media only screen and (max-width: 1200px) {
    .spf-metabox .spf-field .spf-fieldset {
        margin-left: 0;
    }
}

@media only screen and (max-width: 782px) {

    .spf .spf-fieldset,
    .spf .spf-content {
        margin-right: 0;
    }
}

/**
 * 07. Others
 */
.spf-field .spf--transparent-slider {
    margin-left: 0;
    margin-right: 2px;
}

.spf-field .spf--transparent-slider .ui-slider-handle {
    margin: 0 -11px;
}

.spf-field .spf--transparent-offset {
    background-position: center right;
}

.spf-field .spf--transparent-text {
    right: auto;
    left: 10px;
}